#include <Arduino.h>
#include <U8g2lib.h>

#include <SPI.h>

/*
  U8g2lib Example Overview:
    Frame Buffer Examples: clearBuffer/sendBuffer. Fast, but may not work with all Arduino boards because of RAM consumption
    Page Buffer Examples: firstPage/nextPage. Less RAM usage, should work with all Arduino boards.
    U8x8 Text Only Example: No RAM usage, direct communication with display controller. No graphics, 8x8 Text only.
    
  This is a page buffer example.    
*/

// Please UNCOMMENT one of the contructor lines below
// U8g2 Contructor List (Picture Loop Page Buffer)
// The complete list is available here: https://github.com/olikraus/u8g2/wiki/u8g2setupcpp
// Please update the pin numbers according to your setup. Use U8X8_PIN_NONE if the reset pin is not connected

#define OLED_DC  7
#define OLED_CS  10
#define OLED_RST 6
U8G2_SSD1309_128X64_NONAME2_1_4W_HW_SPI u8g2(/* rotation=*/U8G2_MIRROR, /* cs=*/ OLED_CS, /* dc=*/ OLED_DC,/* reset=*/OLED_RST);


void u8g2_prepare(void) {
  u8g2.setFont(u8g2_font_6x10_tf);  //Set the font to "u8g2_font_6x10_tf"
  u8g2.setFontRefHeightExtendedText();  //Ascent will be the largest ascent of "A", "1" or "(" of the current font. Descent will be the descent of "g" or "(" of the current font.
  u8g2.setDrawColor(1); //Ascent will be the largest ascent of "A", "1" or "(" of the current font. Descent will be the descent of "g" or "(" of the current font.
  u8g2.setFontPosTop();  /*When you use drawStr to display strings, the default criteria is to display the lower-left coordinates of the characters.
                        XXXX  */
  u8g2.setFontDirection(0); //Set the screen orientation: 0 -- for normal display
}

// 'frame_00_delay-0', 56x56px
const unsigned char rick_roll_frame_00_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0xf8, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfe, 
  0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0xcf, 0x0e, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x03, 0x0c, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0x04, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x03, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x04, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x02, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x1e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 
  0xff, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x85, 0xfe, 0x03, 0x00, 0x00, 0x00, 0xf0, 0x41, 0xfe, 0x1f, 
  0x00, 0x00, 0x00, 0xf8, 0x09, 0xfe, 0x1f, 0x00, 0x00, 0x00, 0xfc, 0x1f, 0xff, 0x1f, 0x00, 0x00, 
  0x00, 0xfe, 0xef, 0xff, 0x1f, 0x00, 0x00, 0x00, 0xfe, 0xe7, 0xff, 0x1f, 0x00, 0x00, 0x00, 0xfe, 
  0x87, 0xff, 0x1f, 0x00, 0x00, 0x00, 0xfe, 0xc7, 0xff, 0x3f, 0x00, 0x00, 0x00, 0xfe, 0xc7, 0xff, 
  0x3f, 0x00, 0x00, 0x00, 0xfe, 0xff, 0xf9, 0x3f, 0x00, 0x00, 0x00, 0xfe, 0xc7, 0xf5, 0x3f, 0x00, 
  0x00, 0x00, 0xfe, 0xc7, 0xf3, 0x3f, 0x00, 0x00, 0x00, 0xfe, 0xc7, 0xf1, 0x7f, 0x00, 0x00, 0x00, 
  0xfe, 0xe7, 0xe0, 0x7f, 0x00, 0x00, 0x00, 0xfe, 0xe7, 0xf3, 0xff, 0x00, 0x00, 0x00, 0xfe, 0xe7, 
  0xf1, 0xff, 0x00, 0x00, 0x00, 0xfe, 0xf7, 0xf3, 0xff, 0x01, 0x00, 0x00, 0xfe, 0xe7, 0xff, 0xff, 
  0x01, 0x00, 0x00, 0xfe, 0xff, 0xff, 0xff, 0x01, 0x00, 0x00, 0xfe, 0xe7, 0xff, 0xff, 0x00, 0x00, 
  0x00, 0xf0, 0xff, 0xff, 0x7f, 0x00, 0x00, 0x00, 0xf0, 0xe7, 0xff, 0x7f, 0x00, 0x00, 0xc0, 0xe1, 
  0xff, 0xff, 0x3f, 0x00, 0x00, 0x40, 0xf3, 0xe7, 0xff, 0x1f, 0x00, 0x00, 0x80, 0xf2, 0xff, 0xff, 
  0x07, 0x00, 0x00, 0x00, 0xf9, 0xf3, 0xff, 0x07, 0x00, 0x00, 0x00, 0xcc, 0xe3, 0xff, 0x07, 0x00, 
  0x00, 0x00, 0xc6, 0xe3, 0xff, 0x0f, 0x00, 0x00, 0x00, 0xe6, 0xe3, 0xff, 0x0f, 0x00, 0x00, 0x00, 
  0xe0, 0xe3, 0xff, 0x0f, 0x00, 0x00, 0x00, 0xe0, 0xe3, 0xff, 0x1f, 0x00, 0x00, 0x00, 0xe0, 0xe3, 
  0xff, 0x1f, 0x00, 0x00, 0x00, 0xf0, 0xc3, 0xff, 0x1f, 0x00, 0x00, 0x00, 0xf0, 0xc3, 0xff, 0x1f, 
  0x00, 0x00, 0x00, 0xf0, 0x81, 0xff, 0x1f, 0x00
};
// 'frame_01_delay-0', 56x56px
const unsigned char rick_roll_frame_01_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0xf8, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfe, 
  0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0xcf, 0x0e, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x03, 0x0c, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0x04, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x03, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x04, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x02, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x1e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 
  0xff, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x85, 0xfe, 0x03, 0x00, 0x00, 0x00, 0xf0, 0x41, 0xfe, 0x1f, 
  0x00, 0x00, 0x00, 0xf8, 0x09, 0xfe, 0x1f, 0x00, 0x00, 0x00, 0xfc, 0x1f, 0xff, 0x1f, 0x00, 0x00, 
  0x00, 0xfe, 0xef, 0xff, 0x1f, 0x00, 0x00, 0x00, 0xfe, 0xe7, 0xff, 0x1f, 0x00, 0x00, 0x00, 0xfe, 
  0x87, 0xff, 0x1f, 0x00, 0x00, 0x00, 0xfe, 0xc7, 0xff, 0x3f, 0x00, 0x00, 0x00, 0xfe, 0xc7, 0xff, 
  0x3f, 0x00, 0x00, 0x00, 0xfe, 0xff, 0xf9, 0x3f, 0x00, 0x00, 0x00, 0xfe, 0xc7, 0xf5, 0x3f, 0x00, 
  0x00, 0x00, 0xfe, 0xc7, 0xf3, 0x3f, 0x00, 0x00, 0x00, 0xfe, 0xc7, 0xf1, 0x7f, 0x00, 0x00, 0x00, 
  0xfe, 0xe7, 0xe0, 0x7f, 0x00, 0x00, 0x00, 0xfe, 0xe7, 0xf3, 0xff, 0x00, 0x00, 0x00, 0xfe, 0xe7, 
  0xf1, 0xff, 0x00, 0x00, 0x00, 0xfe, 0xf7, 0xf3, 0xff, 0x01, 0x00, 0x00, 0xfe, 0xe7, 0xff, 0xff, 
  0x01, 0x00, 0x00, 0xfe, 0xff, 0xff, 0xff, 0x01, 0x00, 0x00, 0xfe, 0xe7, 0xff, 0xff, 0x00, 0x00, 
  0x00, 0xf0, 0xff, 0xff, 0x7f, 0x00, 0x00, 0x00, 0xf0, 0xe7, 0xff, 0x7f, 0x00, 0x00, 0xc0, 0xe1, 
  0xff, 0xff, 0x3f, 0x00, 0x00, 0x40, 0xf3, 0xe7, 0xff, 0x1f, 0x00, 0x00, 0x80, 0xf2, 0xff, 0xff, 
  0x07, 0x00, 0x00, 0x00, 0xf9, 0xf3, 0xff, 0x07, 0x00, 0x00, 0x00, 0xcc, 0xe3, 0xff, 0x07, 0x00, 
  0x00, 0x00, 0xc6, 0xe3, 0xff, 0x0f, 0x00, 0x00, 0x00, 0xe6, 0xe3, 0xff, 0x0f, 0x00, 0x00, 0x00, 
  0xe0, 0xe3, 0xff, 0x0f, 0x00, 0x00, 0x00, 0xe0, 0xe3, 0xff, 0x1f, 0x00, 0x00, 0x00, 0xe0, 0xe3, 
  0xff, 0x1f, 0x00, 0x00, 0x00, 0xf0, 0xc3, 0xff, 0x1f, 0x00, 0x00, 0x00, 0xf0, 0xc3, 0xff, 0x1f, 
  0x00, 0x00, 0x00, 0xf0, 0x81, 0xff, 0x1f, 0x00
};
// 'frame_02_delay-0', 56x56px
const unsigned char rick_roll_frame_02_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0xff, 
  0x01, 0x00, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x01, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x81, 0x01, 0x00, 
  0x00, 0x00, 0x00, 0xc0, 0x00, 0x03, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x03, 0x00, 0x00, 0x00, 
  0x00, 0x40, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x60, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x38, 0xc0, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x3f, 0xe0, 0x03, 0x00, 0x00, 0x00, 0xe0, 0x1f, 0xd0, 0x0f, 0x00, 
  0x00, 0x00, 0xf0, 0x1f, 0xc8, 0x3f, 0x00, 0x00, 0x00, 0xf0, 0x1f, 0xc0, 0xff, 0x00, 0x00, 0x00, 
  0xf0, 0x3f, 0xe3, 0xe7, 0x01, 0x00, 0x00, 0xf8, 0x7f, 0xf0, 0xc7, 0x03, 0x00, 0x00, 0xf8, 0x7f, 
  0xff, 0x87, 0x03, 0x00, 0x00, 0xf8, 0x3f, 0xfe, 0x0f, 0x03, 0x00, 0x00, 0xfc, 0xff, 0xf7, 0x07, 
  0x03, 0x00, 0x00, 0xfc, 0x7f, 0xfe, 0x8f, 0x03, 0x00, 0x00, 0xfc, 0x7f, 0xf3, 0x8f, 0x03, 0x00, 
  0x00, 0xfe, 0xff, 0xf8, 0x8f, 0x03, 0x00, 0x00, 0xfe, 0x7f, 0xf8, 0x0f, 0x03, 0x00, 0x00, 0xff, 
  0x7f, 0xfe, 0x1f, 0x03, 0x00, 0x00, 0xff, 0x47, 0xfc, 0x3f, 0x07, 0x00, 0x80, 0xff, 0x43, 0xfc, 
  0xff, 0x07, 0x00, 0x80, 0xff, 0x61, 0xf8, 0xff, 0x07, 0x00, 0x80, 0xff, 0x41, 0xfe, 0xff, 0x0f, 
  0x00, 0x80, 0xff, 0x41, 0xfc, 0xff, 0x1f, 0x00, 0x80, 0xff, 0x71, 0xfc, 0xff, 0x3f, 0x00, 0x80, 
  0xff, 0x7f, 0xfe, 0xff, 0x3f, 0x00, 0x00, 0xff, 0x7f, 0xfc, 0xff, 0x3f, 0x00, 0x00, 0xfc, 0x7f, 
  0xfc, 0xff, 0x1f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xff, 0x1f, 0x00, 0x00, 0x80, 0x7f, 0xfc, 0xff, 
  0x0f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xff, 0x07, 0x00, 0x00, 0x80, 0xff, 0xff, 0x7f, 0x00, 0x00, 
  0x00, 0x80, 0x7f, 0xff, 0xff, 0x00, 0x00, 0x00, 0x80, 0x7f, 0xfc, 0xff, 0x00, 0x00, 0x00, 0x80, 
  0x7f, 0xfc, 0xff, 0x01, 0x00, 0x00, 0x80, 0x7f, 0xfc, 0xff, 0x03, 0x00, 0x00, 0x80, 0x7f, 0xfc, 
  0xff, 0x03, 0x00, 0x00, 0x80, 0x7f, 0xfc, 0xff, 0x03, 0x00, 0x00, 0x80, 0x7f, 0xf8, 0xff, 0x03, 
  0x00, 0x00, 0x80, 0x7f, 0xf8, 0xff, 0x03, 0x00
};
// 'frame_03_delay-0', 56x56px
const unsigned char rick_roll_frame_03_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0xff, 
  0x01, 0x00, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x01, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x81, 0x01, 0x00, 
  0x00, 0x00, 0x00, 0xc0, 0x00, 0x03, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x03, 0x00, 0x00, 0x00, 
  0x00, 0x40, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x60, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x38, 0xc0, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x3f, 0xe0, 0x03, 0x00, 0x00, 0x00, 0xe0, 0x1f, 0xd0, 0x0f, 0x00, 
  0x00, 0x00, 0xf0, 0x1f, 0xc8, 0x3f, 0x00, 0x00, 0x00, 0xf0, 0x1f, 0xc0, 0xff, 0x00, 0x00, 0x00, 
  0xf0, 0x3f, 0xe3, 0xe7, 0x01, 0x00, 0x00, 0xf8, 0x7f, 0xf0, 0xc7, 0x03, 0x00, 0x00, 0xf8, 0x7f, 
  0xff, 0x87, 0x03, 0x00, 0x00, 0xf8, 0x3f, 0xfe, 0x0f, 0x03, 0x00, 0x00, 0xfc, 0xff, 0xf7, 0x07, 
  0x03, 0x00, 0x00, 0xfc, 0x7f, 0xfe, 0x8f, 0x03, 0x00, 0x00, 0xfc, 0x7f, 0xf3, 0x8f, 0x03, 0x00, 
  0x00, 0xfe, 0xff, 0xf8, 0x8f, 0x03, 0x00, 0x00, 0xfe, 0x7f, 0xf8, 0x0f, 0x03, 0x00, 0x00, 0xff, 
  0x7f, 0xfe, 0x1f, 0x03, 0x00, 0x00, 0xff, 0x47, 0xfc, 0x3f, 0x07, 0x00, 0x80, 0xff, 0x43, 0xfc, 
  0xff, 0x07, 0x00, 0x80, 0xff, 0x61, 0xf8, 0xff, 0x07, 0x00, 0x80, 0xff, 0x41, 0xfe, 0xff, 0x0f, 
  0x00, 0x80, 0xff, 0x41, 0xfc, 0xff, 0x1f, 0x00, 0x80, 0xff, 0x71, 0xfc, 0xff, 0x3f, 0x00, 0x80, 
  0xff, 0x7f, 0xfe, 0xff, 0x3f, 0x00, 0x00, 0xff, 0x7f, 0xfc, 0xff, 0x3f, 0x00, 0x00, 0xfc, 0x7f, 
  0xfc, 0xff, 0x1f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xff, 0x1f, 0x00, 0x00, 0x80, 0x7f, 0xfc, 0xff, 
  0x0f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xff, 0x07, 0x00, 0x00, 0x80, 0xff, 0xff, 0x7f, 0x00, 0x00, 
  0x00, 0x80, 0x7f, 0xff, 0xff, 0x00, 0x00, 0x00, 0x80, 0x7f, 0xfc, 0xff, 0x00, 0x00, 0x00, 0x80, 
  0x7f, 0xfc, 0xff, 0x01, 0x00, 0x00, 0x80, 0x7f, 0xfc, 0xff, 0x03, 0x00, 0x00, 0x80, 0x7f, 0xfc, 
  0xff, 0x03, 0x00, 0x00, 0x80, 0x7f, 0xfc, 0xff, 0x03, 0x00, 0x00, 0x80, 0x7f, 0xf8, 0xff, 0x03, 
  0x00, 0x00, 0x80, 0x7f, 0xf8, 0xff, 0x03, 0x00
};
// 'frame_04_delay-0', 56x56px
const unsigned char rick_roll_frame_04_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xff, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xff, 0x01, 0x00, 
  0x00, 0x00, 0x00, 0xc0, 0xff, 0x01, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x00, 0x01, 0x00, 0x00, 0x00, 
  0x00, 0x40, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x40, 
  0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x80, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x80, 
  0x01, 0x00, 0x00, 0x00, 0x00, 0x60, 0x80, 0x03, 0x00, 0x00, 0x00, 0x00, 0x78, 0x41, 0x0f, 0x00, 
  0x00, 0x00, 0x00, 0x7e, 0x00, 0x7f, 0x00, 0x00, 0x00, 0x80, 0x7f, 0x20, 0xff, 0x01, 0x00, 0x00, 
  0xc0, 0x7f, 0x10, 0xff, 0x03, 0x00, 0x00, 0xe0, 0x7f, 0x9c, 0xff, 0x07, 0x00, 0x00, 0xe0, 0xff, 
  0xf1, 0xff, 0x07, 0x00, 0x00, 0xf0, 0xff, 0xc1, 0xff, 0x07, 0x00, 0x00, 0xf0, 0xff, 0xc7, 0xff, 
  0x07, 0x00, 0x00, 0xf0, 0xff, 0xc1, 0xff, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xe1, 0xff, 0x0f, 0x00, 
  0x00, 0xf0, 0xff, 0xe1, 0xf9, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xff, 0xe3, 0x0f, 0x00, 0x00, 0xf0, 
  0xff, 0xff, 0xc1, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xe3, 0xc1, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xe3, 
  0xc1, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xe3, 0xc7, 0x07, 0x00, 0x00, 0xf0, 0xff, 0xf3, 0xc3, 0x0f, 
  0x00, 0x00, 0xf0, 0xff, 0xfb, 0xc3, 0x0f, 0x00, 0x00, 0xf8, 0xff, 0xff, 0xc7, 0x1f, 0x00, 0x00, 
  0xf8, 0xff, 0xeb, 0xff, 0x3f, 0x00, 0x00, 0x38, 0xff, 0xe3, 0xff, 0x3f, 0x00, 0x00, 0x68, 0xff, 
  0xe3, 0xff, 0x1f, 0x00, 0x00, 0x40, 0xff, 0xe3, 0xff, 0x0f, 0x00, 0x00, 0x60, 0xff, 0xff, 0xff, 
  0x0f, 0x00, 0x00, 0x20, 0xff, 0xef, 0xff, 0x07, 0x00, 0x00, 0x00, 0xff, 0xeb, 0xff, 0x03, 0x00, 
  0x00, 0xc0, 0xff, 0xff, 0x3f, 0x00, 0x00, 0x00, 0xe0, 0xff, 0xdb, 0x3f, 0x00, 0x00, 0x00, 0xc0, 
  0xff, 0xc3, 0x3f, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x83, 0x3f, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x83, 
  0x3f, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x83, 0x3f, 0x00, 0x00, 0x00, 0xe0, 0xff, 0x03, 0x3f, 0x00, 
  0x00, 0x00, 0xe0, 0xff, 0x03, 0x3f, 0x00, 0x00
};
// 'frame_05_delay-0', 56x56px
const unsigned char rick_roll_frame_05_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xff, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xff, 0x01, 0x00, 
  0x00, 0x00, 0x00, 0xc0, 0xff, 0x01, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x00, 0x01, 0x00, 0x00, 0x00, 
  0x00, 0x40, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x40, 
  0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x80, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x80, 
  0x01, 0x00, 0x00, 0x00, 0x00, 0x60, 0x80, 0x03, 0x00, 0x00, 0x00, 0x00, 0x78, 0x41, 0x0f, 0x00, 
  0x00, 0x00, 0x00, 0x7e, 0x00, 0x7f, 0x00, 0x00, 0x00, 0x80, 0x7f, 0x20, 0xff, 0x01, 0x00, 0x00, 
  0xc0, 0x7f, 0x10, 0xff, 0x03, 0x00, 0x00, 0xe0, 0x7f, 0x9c, 0xff, 0x07, 0x00, 0x00, 0xe0, 0xff, 
  0xf1, 0xff, 0x07, 0x00, 0x00, 0xf0, 0xff, 0xc1, 0xff, 0x07, 0x00, 0x00, 0xf0, 0xff, 0xc7, 0xff, 
  0x07, 0x00, 0x00, 0xf0, 0xff, 0xc1, 0xff, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xe1, 0xff, 0x0f, 0x00, 
  0x00, 0xf0, 0xff, 0xe1, 0xf9, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xff, 0xe3, 0x0f, 0x00, 0x00, 0xf0, 
  0xff, 0xff, 0xc1, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xe3, 0xc1, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xe3, 
  0xc1, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xe3, 0xc7, 0x07, 0x00, 0x00, 0xf0, 0xff, 0xf3, 0xc3, 0x0f, 
  0x00, 0x00, 0xf0, 0xff, 0xfb, 0xc3, 0x0f, 0x00, 0x00, 0xf8, 0xff, 0xff, 0xc7, 0x1f, 0x00, 0x00, 
  0xf8, 0xff, 0xeb, 0xff, 0x3f, 0x00, 0x00, 0x38, 0xff, 0xe3, 0xff, 0x3f, 0x00, 0x00, 0x68, 0xff, 
  0xe3, 0xff, 0x1f, 0x00, 0x00, 0x40, 0xff, 0xe3, 0xff, 0x0f, 0x00, 0x00, 0x60, 0xff, 0xff, 0xff, 
  0x0f, 0x00, 0x00, 0x20, 0xff, 0xef, 0xff, 0x07, 0x00, 0x00, 0x00, 0xff, 0xeb, 0xff, 0x03, 0x00, 
  0x00, 0xc0, 0xff, 0xff, 0x3f, 0x00, 0x00, 0x00, 0xe0, 0xff, 0xdb, 0x3f, 0x00, 0x00, 0x00, 0xc0, 
  0xff, 0xc3, 0x3f, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x83, 0x3f, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x83, 
  0x3f, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x83, 0x3f, 0x00, 0x00, 0x00, 0xe0, 0xff, 0x03, 0x3f, 0x00, 
  0x00, 0x00, 0xe0, 0xff, 0x03, 0x3f, 0x00, 0x00
};
// 'frame_06_delay-0', 56x56px
const unsigned char rick_roll_frame_06_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xff, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x80, 0xff, 0x01, 0x00, 0x00, 0x00, 0x00, 0x80, 0xff, 0x01, 0x00, 0x00, 0x00, 
  0x00, 0x80, 0xc0, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x80, 0x03, 0x00, 0x00, 0x00, 0x00, 0x40, 0x80, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x01, 
  0x00, 0x00, 0x00, 0x00, 0x40, 0x80, 0x01, 0x00, 0x00, 0x00, 0x00, 0x40, 0x80, 0x01, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x80, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x70, 0x00, 0x03, 0x00, 0x00, 0x00, 0x00, 0x7c, 0x40, 0x0f, 0x00, 0x00, 0x00, 
  0x00, 0x7f, 0x01, 0x7f, 0x00, 0x00, 0x00, 0xc0, 0x7f, 0x20, 0xff, 0x03, 0x00, 0x00, 0xe0, 0x7f, 
  0x10, 0xff, 0x03, 0x00, 0x00, 0xf0, 0x7f, 0x8c, 0xff, 0x07, 0x00, 0x00, 0xf0, 0xff, 0xff, 0xff, 
  0x07, 0x00, 0x00, 0xf0, 0xff, 0xff, 0xff, 0x07, 0x00, 0x00, 0xf0, 0xff, 0xff, 0xff, 0x0f, 0x00, 
  0x00, 0xf0, 0xff, 0xff, 0xff, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xff, 0xff, 0x0f, 0x00, 0x00, 0xf0, 
  0xff, 0xff, 0xff, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xdf, 0xff, 0x07, 0x00, 0x00, 0xf0, 0xe7, 0xff, 
  0xdf, 0x07, 0x00, 0x00, 0xf0, 0xe1, 0xc3, 0xbf, 0x07, 0x00, 0x00, 0xf8, 0xf3, 0xf7, 0x1f, 0x06, 
  0x00, 0x00, 0xf8, 0xe5, 0xe7, 0x1f, 0x0c, 0x00, 0x00, 0xf8, 0xe9, 0xc7, 0x1f, 0x0c, 0x00, 0x00, 
  0xf8, 0xf1, 0x87, 0x1f, 0x1e, 0x00, 0x00, 0xf8, 0xf1, 0x87, 0x1f, 0x3e, 0x00, 0x00, 0xf8, 0xf1, 
  0xcf, 0x3f, 0x3f, 0x00, 0x00, 0xf8, 0xff, 0x8f, 0x7f, 0x3f, 0x00, 0x00, 0xf8, 0xff, 0xdf, 0xff, 
  0x3f, 0x00, 0x00, 0xf8, 0xff, 0xff, 0xff, 0x1f, 0x00, 0x00, 0xf8, 0xff, 0xdf, 0xff, 0x1f, 0x00, 
  0x00, 0xf0, 0xff, 0x1f, 0xfe, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xdf, 0xff, 0x07, 0x00, 0x00, 0x00, 
  0xfe, 0xdf, 0xff, 0x00, 0x00, 0x00, 0x00, 0xff, 0xdf, 0xf9, 0x00, 0x00, 0x00, 0x00, 0xff, 0x1f, 
  0xf8, 0x01, 0x00, 0x00, 0x00, 0xff, 0x1f, 0xf0, 0x01, 0x00, 0x00, 0x00, 0xff, 0x1f, 0xf0, 0x03, 
  0x00, 0x00, 0x80, 0xff, 0x1f, 0xe0, 0x03, 0x00
};
// 'frame_07_delay-0', 56x56px
const unsigned char rick_roll_frame_07_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 
  0x0f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x1f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0x3f, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0xfc, 0x3f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x38, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x04, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0xd3, 
  0x04, 0x00, 0x00, 0x00, 0x00, 0x80, 0x07, 0x04, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x07, 0x1c, 0x00, 
  0x00, 0x00, 0x00, 0xf8, 0x03, 0x3a, 0x00, 0x00, 0x00, 0x00, 0xff, 0x0b, 0xf8, 0x00, 0x00, 0x00, 
  0x80, 0xff, 0x03, 0xf9, 0x03, 0x00, 0x00, 0xc0, 0xff, 0x83, 0xf8, 0x07, 0x00, 0x00, 0xc0, 0xff, 
  0x63, 0xf8, 0x1f, 0x00, 0x00, 0xe0, 0xff, 0x7f, 0xf8, 0x3f, 0x00, 0x00, 0xe0, 0xff, 0x0f, 0xff, 
  0x3f, 0x00, 0x00, 0xe0, 0xff, 0xdf, 0xfd, 0x3f, 0x00, 0x00, 0xe0, 0xff, 0xdf, 0xfd, 0x3f, 0x00, 
  0x00, 0xe0, 0xff, 0x9f, 0xfd, 0x3f, 0x00, 0x00, 0xe0, 0xff, 0x7f, 0xfc, 0x3f, 0x00, 0x00, 0xf0, 
  0xff, 0x19, 0xfe, 0x3f, 0x00, 0x00, 0xf0, 0x7f, 0x1c, 0xff, 0x3f, 0x00, 0x00, 0xf8, 0x3f, 0x78, 
  0xfc, 0x3f, 0x00, 0x00, 0xf8, 0x3f, 0x3e, 0xfe, 0x3f, 0x00, 0x00, 0xf8, 0x3f, 0x3c, 0xfe, 0x3f, 
  0x00, 0x00, 0xfc, 0x3f, 0xb8, 0xff, 0x3f, 0x00, 0x00, 0xfc, 0x3f, 0xfe, 0xfc, 0x3f, 0x00, 0x00, 
  0xfc, 0x3f, 0x7e, 0xfc, 0x7f, 0x00, 0x00, 0xfc, 0x3f, 0x3f, 0xfc, 0x7f, 0x00, 0x00, 0xfc, 0xff, 
  0x7f, 0xfd, 0x7f, 0x00, 0x00, 0xfc, 0xff, 0x7f, 0xfc, 0x7f, 0x00, 0x00, 0xfc, 0xff, 0x7f, 0xfc, 
  0x7f, 0x08, 0x00, 0xfc, 0xff, 0x7f, 0xf8, 0x3f, 0x0a, 0x00, 0xf8, 0xff, 0xff, 0xf8, 0x3f, 0x08, 
  0x00, 0xf0, 0xff, 0xff, 0xf9, 0x3f, 0x06, 0x00, 0xf0, 0xff, 0xff, 0xf7, 0x7f, 0x04, 0x00, 0x00, 
  0xfc, 0xff, 0xf3, 0xff, 0x03, 0x00, 0x00, 0xfc, 0xff, 0xfb, 0xff, 0x03, 0x00, 0x00, 0xfe, 0xff, 
  0xe0, 0xff, 0x01, 0x00, 0x00, 0xfe, 0xff, 0xc0, 0x1f, 0x00, 0x00, 0x00, 0xfe, 0xff, 0xc0, 0x07, 
  0x00, 0x00, 0x00, 0xfe, 0xff, 0xc0, 0x0f, 0x00
};
// 'frame_08_delay-0', 56x56px
const unsigned char rick_roll_frame_08_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 
  0x0f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x1f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0x3f, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0xfc, 0x3f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x38, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x04, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0xd3, 
  0x04, 0x00, 0x00, 0x00, 0x00, 0x80, 0x07, 0x04, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x07, 0x1c, 0x00, 
  0x00, 0x00, 0x00, 0xf8, 0x03, 0x3a, 0x00, 0x00, 0x00, 0x00, 0xff, 0x0b, 0xf8, 0x00, 0x00, 0x00, 
  0x80, 0xff, 0x03, 0xf9, 0x03, 0x00, 0x00, 0xc0, 0xff, 0x83, 0xf8, 0x07, 0x00, 0x00, 0xc0, 0xff, 
  0x63, 0xf8, 0x1f, 0x00, 0x00, 0xe0, 0xff, 0x7f, 0xf8, 0x3f, 0x00, 0x00, 0xe0, 0xff, 0x0f, 0xff, 
  0x3f, 0x00, 0x00, 0xe0, 0xff, 0xdf, 0xfd, 0x3f, 0x00, 0x00, 0xe0, 0xff, 0xdf, 0xfd, 0x3f, 0x00, 
  0x00, 0xe0, 0xff, 0x9f, 0xfd, 0x3f, 0x00, 0x00, 0xe0, 0xff, 0x7f, 0xfc, 0x3f, 0x00, 0x00, 0xf0, 
  0xff, 0x19, 0xfe, 0x3f, 0x00, 0x00, 0xf0, 0x7f, 0x1c, 0xff, 0x3f, 0x00, 0x00, 0xf8, 0x3f, 0x78, 
  0xfc, 0x3f, 0x00, 0x00, 0xf8, 0x3f, 0x3e, 0xfe, 0x3f, 0x00, 0x00, 0xf8, 0x3f, 0x3c, 0xfe, 0x3f, 
  0x00, 0x00, 0xfc, 0x3f, 0xb8, 0xff, 0x3f, 0x00, 0x00, 0xfc, 0x3f, 0xfe, 0xfc, 0x3f, 0x00, 0x00, 
  0xfc, 0x3f, 0x7e, 0xfc, 0x7f, 0x00, 0x00, 0xfc, 0x3f, 0x3f, 0xfc, 0x7f, 0x00, 0x00, 0xfc, 0xff, 
  0x7f, 0xfd, 0x7f, 0x00, 0x00, 0xfc, 0xff, 0x7f, 0xfc, 0x7f, 0x00, 0x00, 0xfc, 0xff, 0x7f, 0xfc, 
  0x7f, 0x08, 0x00, 0xfc, 0xff, 0x7f, 0xf8, 0x3f, 0x0a, 0x00, 0xf8, 0xff, 0xff, 0xf8, 0x3f, 0x08, 
  0x00, 0xf0, 0xff, 0xff, 0xf9, 0x3f, 0x06, 0x00, 0xf0, 0xff, 0xff, 0xf7, 0x7f, 0x04, 0x00, 0x00, 
  0xfc, 0xff, 0xf3, 0xff, 0x03, 0x00, 0x00, 0xfc, 0xff, 0xfb, 0xff, 0x03, 0x00, 0x00, 0xfe, 0xff, 
  0xe0, 0xff, 0x01, 0x00, 0x00, 0xfe, 0xff, 0xc0, 0x1f, 0x00, 0x00, 0x00, 0xfe, 0xff, 0xc0, 0x07, 
  0x00, 0x00, 0x00, 0xfe, 0xff, 0xc0, 0x0f, 0x00
};
// 'frame_09_delay-0', 56x56px
const unsigned char rick_roll_frame_09_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfc, 
  0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfe, 0x03, 0x00, 0x00, 0x00, 0x00, 0x80, 0xff, 0x03, 0x00, 
  0x00, 0x00, 0x00, 0x80, 0xff, 0x03, 0x00, 0x00, 0x00, 0x00, 0x80, 0x1f, 0x02, 0x00, 0x00, 0x00, 
  0x00, 0xc0, 0x0f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x0f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 
  0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x04, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x01, 0x02, 0x00, 0x00, 
  0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0xc0, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 0x40, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x7e, 0xc1, 0x03, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x82, 0x0f, 0x00, 
  0x00, 0x00, 0xe0, 0xff, 0x20, 0x3f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x80, 0x7f, 0x00, 0x00, 0x00, 
  0xf0, 0xff, 0xbd, 0xff, 0x00, 0x00, 0x00, 0xf0, 0xff, 0xe3, 0xff, 0x00, 0x00, 0x00, 0xf8, 0xff, 
  0xff, 0xff, 0x00, 0x00, 0x00, 0xf8, 0xff, 0xff, 0xff, 0x00, 0x00, 0x00, 0xf8, 0xff, 0xff, 0xff, 
  0x00, 0x00, 0x00, 0xf8, 0xff, 0xf7, 0xff, 0x00, 0x00, 0x00, 0xfc, 0xff, 0xff, 0xff, 0x01, 0x00, 
  0x00, 0xfc, 0xff, 0xff, 0xff, 0x01, 0x00, 0x00, 0xfc, 0xff, 0xcf, 0xff, 0x01, 0x00, 0x00, 0xfe, 
  0xff, 0xff, 0xff, 0x01, 0x00, 0x00, 0xfe, 0xff, 0x0f, 0xff, 0x01, 0x00, 0x00, 0xfe, 0xff, 0x83, 
  0xff, 0x01, 0x00, 0x00, 0xfe, 0xff, 0xc1, 0xff, 0x01, 0x00, 0x00, 0xfe, 0xff, 0x83, 0xff, 0x01, 
  0x00, 0x00, 0xfe, 0xff, 0xc3, 0xff, 0x03, 0x00, 0x00, 0xfe, 0xff, 0xe3, 0xff, 0x0f, 0x01, 0x00, 
  0xfe, 0xff, 0xff, 0xff, 0x7f, 0x01, 0x00, 0xfe, 0xff, 0xff, 0xff, 0x1f, 0x18, 0x00, 0xfc, 0xff, 
  0xff, 0xff, 0x1f, 0x78, 0x00, 0xf8, 0xff, 0xbf, 0xff, 0x1f, 0x10, 0x00, 0x80, 0xff, 0xff, 0xff, 
  0x3f, 0x78, 0x00, 0x80, 0xff, 0xff, 0x3f, 0x7c, 0x1d, 0x00, 0x80, 0xff, 0xbf, 0x3f, 0xc0, 0x14, 
  0x00, 0x80, 0xff, 0x3f, 0x3f, 0x00, 0x00, 0x00, 0x80, 0xff, 0x3f, 0x3f, 0x00, 0x00, 0x00, 0x80, 
  0xff, 0x3f, 0x3f, 0x00, 0x00, 0x00, 0x80, 0xff, 0x3f, 0x3e, 0x00, 0x00, 0x00, 0x80, 0xff, 0x3f, 
  0x3e, 0x00, 0x00, 0x00, 0x80, 0xff, 0x3f, 0x3c, 0x00, 0x00, 0x00, 0x80, 0xff, 0x3f, 0x3c, 0x00, 
  0x00, 0x00, 0x80, 0xff, 0x7f, 0x38, 0x00, 0x00
};
// 'frame_10_delay-0', 56x56px
const unsigned char rick_roll_frame_10_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfc, 
  0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfe, 0x03, 0x00, 0x00, 0x00, 0x00, 0x80, 0xff, 0x03, 0x00, 
  0x00, 0x00, 0x00, 0x80, 0xff, 0x03, 0x00, 0x00, 0x00, 0x00, 0x80, 0x1f, 0x02, 0x00, 0x00, 0x00, 
  0x00, 0xc0, 0x0f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x0f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 
  0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x04, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x01, 0x02, 0x00, 0x00, 
  0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0xc0, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 0x40, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x7e, 0xc1, 0x03, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x82, 0x0f, 0x00, 
  0x00, 0x00, 0xe0, 0xff, 0x20, 0x3f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x80, 0x7f, 0x00, 0x00, 0x00, 
  0xf0, 0xff, 0xbd, 0xff, 0x00, 0x00, 0x00, 0xf0, 0xff, 0xe3, 0xff, 0x00, 0x00, 0x00, 0xf8, 0xff, 
  0xff, 0xff, 0x00, 0x00, 0x00, 0xf8, 0xff, 0xff, 0xff, 0x00, 0x00, 0x00, 0xf8, 0xff, 0xff, 0xff, 
  0x00, 0x00, 0x00, 0xf8, 0xff, 0xf7, 0xff, 0x00, 0x00, 0x00, 0xfc, 0xff, 0xff, 0xff, 0x01, 0x00, 
  0x00, 0xfc, 0xff, 0xff, 0xff, 0x01, 0x00, 0x00, 0xfc, 0xff, 0xcf, 0xff, 0x01, 0x00, 0x00, 0xfe, 
  0xff, 0xff, 0xff, 0x01, 0x00, 0x00, 0xfe, 0xff, 0x0f, 0xff, 0x01, 0x00, 0x00, 0xfe, 0xff, 0x83, 
  0xff, 0x01, 0x00, 0x00, 0xfe, 0xff, 0xc1, 0xff, 0x01, 0x00, 0x00, 0xfe, 0xff, 0x83, 0xff, 0x01, 
  0x00, 0x00, 0xfe, 0xff, 0xc3, 0xff, 0x03, 0x00, 0x00, 0xfe, 0xff, 0xe3, 0xff, 0x0f, 0x01, 0x00, 
  0xfe, 0xff, 0xff, 0xff, 0x7f, 0x01, 0x00, 0xfe, 0xff, 0xff, 0xff, 0x1f, 0x18, 0x00, 0xfc, 0xff, 
  0xff, 0xff, 0x1f, 0x78, 0x00, 0xf8, 0xff, 0xbf, 0xff, 0x1f, 0x10, 0x00, 0x80, 0xff, 0xff, 0xff, 
  0x3f, 0x78, 0x00, 0x80, 0xff, 0xff, 0x3f, 0x7c, 0x1d, 0x00, 0x80, 0xff, 0xbf, 0x3f, 0xc0, 0x14, 
  0x00, 0x80, 0xff, 0x3f, 0x3f, 0x00, 0x00, 0x00, 0x80, 0xff, 0x3f, 0x3f, 0x00, 0x00, 0x00, 0x80, 
  0xff, 0x3f, 0x3f, 0x00, 0x00, 0x00, 0x80, 0xff, 0x3f, 0x3e, 0x00, 0x00, 0x00, 0x80, 0xff, 0x3f, 
  0x3e, 0x00, 0x00, 0x00, 0x80, 0xff, 0x3f, 0x3c, 0x00, 0x00, 0x00, 0x80, 0xff, 0x3f, 0x3c, 0x00, 
  0x00, 0x00, 0x80, 0xff, 0x7f, 0x38, 0x00, 0x00
};
// 'frame_11_delay-0', 56x56px
const unsigned char rick_roll_frame_11_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x3f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x7f, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0x7f, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0xf8, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x78, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 
  0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x60, 0x40, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x30, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x38, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1c, 0xf0, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x1f, 0xe0, 0x03, 0x00, 0x00, 0x00, 0xc0, 0x1f, 0xe0, 0x0f, 0x00, 
  0x00, 0x00, 0xf0, 0x9f, 0xc0, 0x1f, 0x00, 0x00, 0x00, 0xfc, 0x1f, 0xe5, 0x3f, 0x00, 0x00, 0x00, 
  0xfe, 0x3f, 0xe3, 0x3f, 0x00, 0x00, 0x00, 0xfe, 0xff, 0xff, 0x7f, 0x00, 0x00, 0x00, 0xfe, 0xff, 
  0xf0, 0x7f, 0x00, 0x00, 0x00, 0xfe, 0xff, 0xf1, 0x7f, 0x00, 0x00, 0x00, 0xff, 0xff, 0xfb, 0x7f, 
  0x00, 0x00, 0x00, 0xff, 0xff, 0xf0, 0x7f, 0x00, 0x00, 0x00, 0xff, 0xff, 0xff, 0x7f, 0x00, 0x00, 
  0x00, 0xff, 0xff, 0xff, 0x7f, 0x00, 0x00, 0x00, 0xff, 0xff, 0xfd, 0x7f, 0x00, 0x00, 0x00, 0xff, 
  0xff, 0xf3, 0x7f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xf3, 0x7f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xf3, 
  0x7f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xf3, 0x6f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xff, 0x87, 0x00, 
  0x00, 0x80, 0xff, 0xff, 0xf7, 0x2f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xff, 0x0f, 0x00, 0x00, 0xc0, 
  0xff, 0xff, 0xff, 0x8f, 0x00, 0x00, 0xc0, 0xff, 0x7f, 0xfe, 0x8f, 0x00, 0x00, 0x80, 0xff, 0x9f, 
  0xf7, 0x1f, 0x00, 0x00, 0x00, 0xff, 0x4f, 0xfc, 0xff, 0x00, 0x00, 0x00, 0xff, 0x87, 0xed, 0x7f, 
  0x00, 0x00, 0x00, 0xfe, 0x07, 0xff, 0x7f, 0x00, 0x00, 0x00, 0xfc, 0x07, 0xee, 0x07, 0x00, 0x00, 
  0x00, 0xf0, 0x07, 0xcf, 0x0f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0xcf, 0x0f, 0x00, 0x00, 0x00, 0xf0, 
  0xff, 0xcf, 0x0f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 0x0f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 
  0x1f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 0x1f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 0x1f, 0x00, 
  0x00, 0x00, 0xf0, 0xff, 0x0f, 0x1f, 0x00, 0x00
};
// 'frame_12_delay-0', 56x56px
const unsigned char rick_roll_frame_12_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x3f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x7f, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0x7f, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0xf8, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x78, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 
  0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x60, 0x40, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x30, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x38, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1c, 0xf0, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x1f, 0xe0, 0x03, 0x00, 0x00, 0x00, 0xc0, 0x1f, 0xe0, 0x0f, 0x00, 
  0x00, 0x00, 0xf0, 0x9f, 0xc0, 0x1f, 0x00, 0x00, 0x00, 0xfc, 0x1f, 0xe5, 0x3f, 0x00, 0x00, 0x00, 
  0xfe, 0x3f, 0xe3, 0x3f, 0x00, 0x00, 0x00, 0xfe, 0xff, 0xff, 0x7f, 0x00, 0x00, 0x00, 0xfe, 0xff, 
  0xf0, 0x7f, 0x00, 0x00, 0x00, 0xfe, 0xff, 0xf1, 0x7f, 0x00, 0x00, 0x00, 0xff, 0xff, 0xfb, 0x7f, 
  0x00, 0x00, 0x00, 0xff, 0xff, 0xf0, 0x7f, 0x00, 0x00, 0x00, 0xff, 0xff, 0xff, 0x7f, 0x00, 0x00, 
  0x00, 0xff, 0xff, 0xff, 0x7f, 0x00, 0x00, 0x00, 0xff, 0xff, 0xfd, 0x7f, 0x00, 0x00, 0x00, 0xff, 
  0xff, 0xf3, 0x7f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xf3, 0x7f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xf3, 
  0x7f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xf3, 0x6f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xff, 0x87, 0x00, 
  0x00, 0x80, 0xff, 0xff, 0xf7, 0x2f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xff, 0x0f, 0x00, 0x00, 0xc0, 
  0xff, 0xff, 0xff, 0x8f, 0x00, 0x00, 0xc0, 0xff, 0x7f, 0xfe, 0x8f, 0x00, 0x00, 0x80, 0xff, 0x9f, 
  0xf7, 0x1f, 0x00, 0x00, 0x00, 0xff, 0x4f, 0xfc, 0xff, 0x00, 0x00, 0x00, 0xff, 0x87, 0xed, 0x7f, 
  0x00, 0x00, 0x00, 0xfe, 0x07, 0xff, 0x7f, 0x00, 0x00, 0x00, 0xfc, 0x07, 0xee, 0x07, 0x00, 0x00, 
  0x00, 0xf0, 0x07, 0xcf, 0x0f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0xcf, 0x0f, 0x00, 0x00, 0x00, 0xf0, 
  0xff, 0xcf, 0x0f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 0x0f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 
  0x1f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 0x1f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 0x1f, 0x00, 
  0x00, 0x00, 0xf0, 0xff, 0x0f, 0x1f, 0x00, 0x00
};
// 'frame_13_delay-0', 56x56px
const unsigned char rick_roll_frame_13_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x3f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x7f, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0x7f, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0xf8, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x78, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 
  0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x60, 0x40, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x30, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x38, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1c, 0xf0, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x1f, 0xe0, 0x03, 0x00, 0x00, 0x00, 0xc0, 0x1f, 0xe0, 0x0f, 0x00, 
  0x00, 0x00, 0xf0, 0x9f, 0xc0, 0x1f, 0x00, 0x00, 0x00, 0xfc, 0x1f, 0xe5, 0x3f, 0x00, 0x00, 0x00, 
  0xfe, 0x3f, 0xe3, 0x3f, 0x00, 0x00, 0x00, 0xfe, 0xff, 0xff, 0x7f, 0x00, 0x00, 0x00, 0xfe, 0xff, 
  0xf0, 0x7f, 0x00, 0x00, 0x00, 0xfe, 0xff, 0xf1, 0x7f, 0x00, 0x00, 0x00, 0xff, 0xff, 0xfb, 0x7f, 
  0x00, 0x00, 0x00, 0xff, 0xff, 0xf0, 0x7f, 0x00, 0x00, 0x00, 0xff, 0xff, 0xff, 0x7f, 0x00, 0x00, 
  0x00, 0xff, 0xff, 0xff, 0x7f, 0x00, 0x00, 0x00, 0xff, 0xff, 0xfd, 0x7f, 0x00, 0x00, 0x00, 0xff, 
  0xff, 0xf3, 0x7f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xf3, 0x7f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xf3, 
  0x7f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xf3, 0x6f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xff, 0x87, 0x00, 
  0x00, 0x80, 0xff, 0xff, 0xf7, 0x2f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xff, 0x0f, 0x00, 0x00, 0xc0, 
  0xff, 0xff, 0xff, 0x8f, 0x00, 0x00, 0xc0, 0xff, 0x7f, 0xfe, 0x8f, 0x00, 0x00, 0x80, 0xff, 0x9f, 
  0xf7, 0x1f, 0x00, 0x00, 0x00, 0xff, 0x4f, 0xfc, 0xff, 0x00, 0x00, 0x00, 0xff, 0x87, 0xed, 0x7f, 
  0x00, 0x00, 0x00, 0xfe, 0x07, 0xff, 0x7f, 0x00, 0x00, 0x00, 0xfc, 0x07, 0xee, 0x07, 0x00, 0x00, 
  0x00, 0xf0, 0x07, 0xcf, 0x0f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0xcf, 0x0f, 0x00, 0x00, 0x00, 0xf0, 
  0xff, 0xcf, 0x0f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 0x0f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 
  0x1f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 0x1f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 0x1f, 0x00, 
  0x00, 0x00, 0xf0, 0xff, 0x0f, 0x1f, 0x00, 0x00
};
// 'frame_14_delay-0', 56x56px
const unsigned char rick_roll_frame_14_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x1f, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x7f, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0xf0, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x60, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x10, 0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 
  0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x80, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x20, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc2, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x20, 0x80, 0x07, 0x00, 0x00, 0x00, 0x00, 0x70, 0x00, 0x7f, 0x00, 
  0x00, 0x00, 0x00, 0x7c, 0x00, 0xff, 0x01, 0x00, 0x00, 0x00, 0xbf, 0x20, 0xff, 0x07, 0x00, 0x00, 
  0xc0, 0x3f, 0x01, 0xff, 0x07, 0x00, 0x00, 0xf0, 0x3f, 0x12, 0xff, 0x07, 0x00, 0x00, 0xf0, 0x3f, 
  0x0c, 0xff, 0x07, 0x00, 0x00, 0xf8, 0x7f, 0xf7, 0xff, 0x07, 0x00, 0x00, 0xf8, 0xff, 0x81, 0xff, 
  0x07, 0x00, 0x00, 0xf8, 0xff, 0x80, 0xff, 0x0f, 0x00, 0x00, 0xf8, 0xff, 0x83, 0xff, 0x0f, 0x00, 
  0x00, 0xf8, 0xff, 0x81, 0xff, 0x0f, 0x00, 0x00, 0xf8, 0xff, 0xff, 0xff, 0x0f, 0x00, 0x00, 0xf8, 
  0xff, 0xc3, 0xff, 0x0f, 0x00, 0x00, 0xf8, 0xff, 0x83, 0xff, 0x1f, 0x00, 0x00, 0xf8, 0xff, 0x83, 
  0xff, 0x1f, 0x00, 0x00, 0xf8, 0xff, 0x87, 0xff, 0x1f, 0x00, 0x00, 0xf8, 0xff, 0x87, 0xff, 0x1f, 
  0x00, 0x00, 0xf8, 0xff, 0x87, 0x3f, 0x3e, 0x00, 0x00, 0xf8, 0xff, 0x87, 0x7f, 0x7c, 0x00, 0x00, 
  0xf8, 0xff, 0xff, 0x3f, 0x38, 0x00, 0x00, 0xec, 0xff, 0x87, 0x1f, 0x18, 0x00, 0x00, 0x98, 0xff, 
  0x07, 0x7f, 0x1c, 0x00, 0x00, 0x60, 0xff, 0x7f, 0x7f, 0x1c, 0x00, 0x00, 0xcc, 0xfe, 0x1f, 0xff, 
  0x0f, 0x00, 0x00, 0x08, 0xfe, 0xff, 0xfe, 0x03, 0x00, 0x00, 0xd8, 0xff, 0x0f, 0xfe, 0x01, 0x00, 
  0x00, 0x98, 0xff, 0x3f, 0x7e, 0x00, 0x00, 0x00, 0xd8, 0xff, 0xbf, 0x7f, 0x00, 0x00, 0x00, 0xf0, 
  0xff, 0xbf, 0xff, 0x00, 0x00, 0x00, 0x80, 0xff, 0x0f, 0xf8, 0x00, 0x00, 0x00, 0x80, 0xff, 0x0f, 
  0xf8, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x0f, 0xf0, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x0f, 0xf0, 0x00, 
  0x00, 0x00, 0xc0, 0xff, 0x0f, 0xe0, 0x01, 0x00
};
// 'frame_15_delay-0', 56x56px
const unsigned char rick_roll_frame_15_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x1f, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x7f, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0xf0, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x60, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x10, 0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 
  0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x80, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x20, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc2, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x20, 0x80, 0x07, 0x00, 0x00, 0x00, 0x00, 0x70, 0x00, 0x7f, 0x00, 
  0x00, 0x00, 0x00, 0x7c, 0x00, 0xff, 0x01, 0x00, 0x00, 0x00, 0xbf, 0x20, 0xff, 0x07, 0x00, 0x00, 
  0xc0, 0x3f, 0x01, 0xff, 0x07, 0x00, 0x00, 0xf0, 0x3f, 0x12, 0xff, 0x07, 0x00, 0x00, 0xf0, 0x3f, 
  0x0c, 0xff, 0x07, 0x00, 0x00, 0xf8, 0x7f, 0xf7, 0xff, 0x07, 0x00, 0x00, 0xf8, 0xff, 0x81, 0xff, 
  0x07, 0x00, 0x00, 0xf8, 0xff, 0x80, 0xff, 0x0f, 0x00, 0x00, 0xf8, 0xff, 0x83, 0xff, 0x0f, 0x00, 
  0x00, 0xf8, 0xff, 0x81, 0xff, 0x0f, 0x00, 0x00, 0xf8, 0xff, 0xff, 0xff, 0x0f, 0x00, 0x00, 0xf8, 
  0xff, 0xc3, 0xff, 0x0f, 0x00, 0x00, 0xf8, 0xff, 0x83, 0xff, 0x1f, 0x00, 0x00, 0xf8, 0xff, 0x83, 
  0xff, 0x1f, 0x00, 0x00, 0xf8, 0xff, 0x87, 0xff, 0x1f, 0x00, 0x00, 0xf8, 0xff, 0x87, 0xff, 0x1f, 
  0x00, 0x00, 0xf8, 0xff, 0x87, 0x3f, 0x3e, 0x00, 0x00, 0xf8, 0xff, 0x87, 0x7f, 0x7c, 0x00, 0x00, 
  0xf8, 0xff, 0xff, 0x3f, 0x38, 0x00, 0x00, 0xec, 0xff, 0x87, 0x1f, 0x18, 0x00, 0x00, 0x98, 0xff, 
  0x07, 0x7f, 0x1c, 0x00, 0x00, 0x60, 0xff, 0x7f, 0x7f, 0x1c, 0x00, 0x00, 0xcc, 0xfe, 0x1f, 0xff, 
  0x0f, 0x00, 0x00, 0x08, 0xfe, 0xff, 0xfe, 0x03, 0x00, 0x00, 0xd8, 0xff, 0x0f, 0xfe, 0x01, 0x00, 
  0x00, 0x98, 0xff, 0x3f, 0x7e, 0x00, 0x00, 0x00, 0xd8, 0xff, 0xbf, 0x7f, 0x00, 0x00, 0x00, 0xf0, 
  0xff, 0xbf, 0xff, 0x00, 0x00, 0x00, 0x80, 0xff, 0x0f, 0xf8, 0x00, 0x00, 0x00, 0x80, 0xff, 0x0f, 
  0xf8, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x0f, 0xf0, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x0f, 0xf0, 0x00, 
  0x00, 0x00, 0xc0, 0xff, 0x0f, 0xe0, 0x01, 0x00
};
// 'frame_16_delay-0', 56x56px
const unsigned char rick_roll_frame_16_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x1f, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x7f, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0xf0, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x60, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x10, 0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 
  0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x80, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x20, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc2, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x20, 0x80, 0x07, 0x00, 0x00, 0x00, 0x00, 0x70, 0x00, 0x7f, 0x00, 
  0x00, 0x00, 0x00, 0x7c, 0x00, 0xff, 0x01, 0x00, 0x00, 0x00, 0xbf, 0x20, 0xff, 0x07, 0x00, 0x00, 
  0xc0, 0x3f, 0x01, 0xff, 0x07, 0x00, 0x00, 0xf0, 0x3f, 0x12, 0xff, 0x07, 0x00, 0x00, 0xf0, 0x3f, 
  0x0c, 0xff, 0x07, 0x00, 0x00, 0xf8, 0x7f, 0xf7, 0xff, 0x07, 0x00, 0x00, 0xf8, 0xff, 0x81, 0xff, 
  0x07, 0x00, 0x00, 0xf8, 0xff, 0x80, 0xff, 0x0f, 0x00, 0x00, 0xf8, 0xff, 0x83, 0xff, 0x0f, 0x00, 
  0x00, 0xf8, 0xff, 0x81, 0xff, 0x0f, 0x00, 0x00, 0xf8, 0xff, 0xff, 0xff, 0x0f, 0x00, 0x00, 0xf8, 
  0xff, 0xc3, 0xff, 0x0f, 0x00, 0x00, 0xf8, 0xff, 0x83, 0xff, 0x1f, 0x00, 0x00, 0xf8, 0xff, 0x83, 
  0xff, 0x1f, 0x00, 0x00, 0xf8, 0xff, 0x87, 0xff, 0x1f, 0x00, 0x00, 0xf8, 0xff, 0x87, 0xff, 0x1f, 
  0x00, 0x00, 0xf8, 0xff, 0x87, 0x3f, 0x3e, 0x00, 0x00, 0xf8, 0xff, 0x87, 0x7f, 0x7c, 0x00, 0x00, 
  0xf8, 0xff, 0xff, 0x3f, 0x38, 0x00, 0x00, 0xec, 0xff, 0x87, 0x1f, 0x18, 0x00, 0x00, 0x98, 0xff, 
  0x07, 0x7f, 0x1c, 0x00, 0x00, 0x60, 0xff, 0x7f, 0x7f, 0x1c, 0x00, 0x00, 0xcc, 0xfe, 0x1f, 0xff, 
  0x0f, 0x00, 0x00, 0x08, 0xfe, 0xff, 0xfe, 0x03, 0x00, 0x00, 0xd8, 0xff, 0x0f, 0xfe, 0x01, 0x00, 
  0x00, 0x98, 0xff, 0x3f, 0x7e, 0x00, 0x00, 0x00, 0xd8, 0xff, 0xbf, 0x7f, 0x00, 0x00, 0x00, 0xf0, 
  0xff, 0xbf, 0xff, 0x00, 0x00, 0x00, 0x80, 0xff, 0x0f, 0xf8, 0x00, 0x00, 0x00, 0x80, 0xff, 0x0f, 
  0xf8, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x0f, 0xf0, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x0f, 0xf0, 0x00, 
  0x00, 0x00, 0xc0, 0xff, 0x0f, 0xe0, 0x01, 0x00
};
// 'frame_17_delay-0', 56x56px
const unsigned char rick_roll_frame_17_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0xf8, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfe, 
  0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0xcf, 0x0e, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x03, 0x0c, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0x04, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x03, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x04, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x02, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x1e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 
  0xff, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x85, 0xfe, 0x03, 0x00, 0x00, 0x00, 0xf0, 0x41, 0xfe, 0x1f, 
  0x00, 0x00, 0x00, 0xf8, 0x09, 0xfe, 0x1f, 0x00, 0x00, 0x00, 0xfc, 0x1f, 0xff, 0x1f, 0x00, 0x00, 
  0x00, 0xfe, 0xef, 0xff, 0x1f, 0x00, 0x00, 0x00, 0xfe, 0xe7, 0xff, 0x1f, 0x00, 0x00, 0x00, 0xfe, 
  0x87, 0xff, 0x1f, 0x00, 0x00, 0x00, 0xfe, 0xc7, 0xff, 0x3f, 0x00, 0x00, 0x00, 0xfe, 0xc7, 0xff, 
  0x3f, 0x00, 0x00, 0x00, 0xfe, 0xff, 0xf9, 0x3f, 0x00, 0x00, 0x00, 0xfe, 0xc7, 0xf5, 0x3f, 0x00, 
  0x00, 0x00, 0xfe, 0xc7, 0xf3, 0x3f, 0x00, 0x00, 0x00, 0xfe, 0xe7, 0xf1, 0x7f, 0x00, 0x00, 0x00, 
  0xfe, 0xe7, 0xe0, 0x7f, 0x00, 0x00, 0x00, 0xfe, 0xe7, 0xf3, 0xff, 0x00, 0x00, 0x00, 0xfe, 0xe7, 
  0xf1, 0xff, 0x00, 0x00, 0x00, 0xfe, 0xf7, 0xf3, 0xff, 0x01, 0x00, 0x00, 0xfe, 0xe7, 0xff, 0xff, 
  0x01, 0x00, 0x00, 0xfe, 0xff, 0xff, 0xff, 0x01, 0x00, 0x00, 0xfe, 0xe7, 0xff, 0xff, 0x00, 0x00, 
  0x00, 0xf0, 0xff, 0xff, 0x7f, 0x00, 0x00, 0x00, 0xf0, 0xe7, 0xff, 0x7f, 0x00, 0x00, 0xc0, 0xe1, 
  0xff, 0xff, 0x3f, 0x00, 0x00, 0x40, 0xf3, 0xe7, 0xff, 0x1f, 0x00, 0x00, 0x80, 0xf2, 0xff, 0xff, 
  0x07, 0x00, 0x00, 0x00, 0xf9, 0xf3, 0xff, 0x07, 0x00, 0x00, 0x00, 0xcc, 0xe3, 0xff, 0x07, 0x00, 
  0x00, 0x00, 0xc6, 0xe3, 0xff, 0x0f, 0x00, 0x00, 0x00, 0xe6, 0xe3, 0xff, 0x0f, 0x00, 0x00, 0x00, 
  0xe0, 0xe3, 0xff, 0x0f, 0x00, 0x00, 0x00, 0xe0, 0xe3, 0xff, 0x1f, 0x00, 0x00, 0x00, 0xe0, 0xe3, 
  0xff, 0x1f, 0x00, 0x00, 0x00, 0xf0, 0xc3, 0xff, 0x1f, 0x00, 0x00, 0x00, 0xf0, 0xc3, 0xff, 0x1f, 
  0x00, 0x00, 0x00, 0xf0, 0x81, 0xff, 0x1f, 0x00
};
// 'frame_18_delay-0', 56x56px
const unsigned char rick_roll_frame_18_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0xff, 
  0x01, 0x00, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x01, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x81, 0x01, 0x00, 
  0x00, 0x00, 0x00, 0xc0, 0x00, 0x03, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x03, 0x00, 0x00, 0x00, 
  0x00, 0x40, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x60, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x38, 0xc0, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x3f, 0xe0, 0x03, 0x00, 0x00, 0x00, 0xe0, 0x1f, 0xd0, 0x0f, 0x00, 
  0x00, 0x00, 0xf0, 0x1f, 0xc8, 0x3f, 0x00, 0x00, 0x00, 0xf0, 0x1f, 0xc0, 0xff, 0x00, 0x00, 0x00, 
  0xf0, 0x3f, 0xe3, 0xe7, 0x01, 0x00, 0x00, 0xf8, 0x7f, 0xf0, 0xc7, 0x03, 0x00, 0x00, 0xf8, 0x7f, 
  0xff, 0x87, 0x03, 0x00, 0x00, 0xf8, 0x3f, 0xfe, 0x0f, 0x03, 0x00, 0x00, 0xfc, 0xff, 0xf7, 0x07, 
  0x03, 0x00, 0x00, 0xfc, 0x7f, 0xfe, 0x8f, 0x03, 0x00, 0x00, 0xfc, 0x7f, 0xf3, 0x8f, 0x03, 0x00, 
  0x00, 0xfe, 0xff, 0xf8, 0x8f, 0x03, 0x00, 0x00, 0xfe, 0x7f, 0xf8, 0x0f, 0x03, 0x00, 0x00, 0xff, 
  0x7f, 0xfe, 0x1f, 0x03, 0x00, 0x00, 0xff, 0x47, 0xfc, 0x3f, 0x07, 0x00, 0x80, 0xff, 0x43, 0xfc, 
  0xff, 0x07, 0x00, 0x80, 0xff, 0x61, 0xf8, 0xff, 0x07, 0x00, 0x80, 0xff, 0x01, 0xfe, 0xff, 0x0f, 
  0x00, 0x80, 0xff, 0x41, 0xfc, 0xff, 0x1f, 0x00, 0x80, 0xff, 0x71, 0xfc, 0xff, 0x3f, 0x00, 0x80, 
  0xff, 0x7f, 0xfe, 0xff, 0x3f, 0x00, 0x00, 0xff, 0x7f, 0xfc, 0xff, 0x3f, 0x00, 0x00, 0xfc, 0x7f, 
  0xfc, 0xff, 0x1f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xff, 0x1f, 0x00, 0x00, 0x80, 0x7f, 0xfc, 0xff, 
  0x0f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xff, 0x07, 0x00, 0x00, 0x80, 0xff, 0xff, 0x7f, 0x00, 0x00, 
  0x00, 0x80, 0x7f, 0xff, 0xff, 0x00, 0x00, 0x00, 0x80, 0x7f, 0xfc, 0xff, 0x01, 0x00, 0x00, 0x80, 
  0x7f, 0xfc, 0xff, 0x01, 0x00, 0x00, 0x80, 0x7f, 0xfc, 0xff, 0x03, 0x00, 0x00, 0x80, 0x7f, 0xfc, 
  0xff, 0x03, 0x00, 0x00, 0x80, 0x7f, 0xfc, 0xff, 0x03, 0x00, 0x00, 0x80, 0x7f, 0xf8, 0xff, 0x03, 
  0x00, 0x00, 0x80, 0x7f, 0xf8, 0xff, 0x03, 0x00
};
// 'frame_19_delay-0', 56x56px
const unsigned char rick_roll_frame_19_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0xff, 
  0x01, 0x00, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x01, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x81, 0x01, 0x00, 
  0x00, 0x00, 0x00, 0xc0, 0x00, 0x03, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x03, 0x00, 0x00, 0x00, 
  0x00, 0x40, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x60, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x38, 0xc0, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x3f, 0xe0, 0x03, 0x00, 0x00, 0x00, 0xe0, 0x1f, 0xd0, 0x0f, 0x00, 
  0x00, 0x00, 0xf0, 0x1f, 0xc8, 0x3f, 0x00, 0x00, 0x00, 0xf0, 0x1f, 0xc0, 0xff, 0x00, 0x00, 0x00, 
  0xf0, 0x3f, 0xe3, 0xe7, 0x01, 0x00, 0x00, 0xf8, 0x7f, 0xf0, 0xc7, 0x03, 0x00, 0x00, 0xf8, 0x7f, 
  0xff, 0x87, 0x03, 0x00, 0x00, 0xf8, 0x3f, 0xfe, 0x0f, 0x03, 0x00, 0x00, 0xfc, 0xff, 0xf7, 0x07, 
  0x03, 0x00, 0x00, 0xfc, 0x7f, 0xfe, 0x8f, 0x03, 0x00, 0x00, 0xfc, 0x7f, 0xf3, 0x8f, 0x03, 0x00, 
  0x00, 0xfe, 0xff, 0xf8, 0x8f, 0x03, 0x00, 0x00, 0xfe, 0x7f, 0xf8, 0x0f, 0x03, 0x00, 0x00, 0xff, 
  0x7f, 0xfe, 0x1f, 0x03, 0x00, 0x00, 0xff, 0x47, 0xfc, 0x3f, 0x07, 0x00, 0x80, 0xff, 0x43, 0xfc, 
  0xff, 0x07, 0x00, 0x80, 0xff, 0x61, 0xf8, 0xff, 0x07, 0x00, 0x80, 0xff, 0x01, 0xfe, 0xff, 0x0f, 
  0x00, 0x80, 0xff, 0x41, 0xfc, 0xff, 0x1f, 0x00, 0x80, 0xff, 0x71, 0xfc, 0xff, 0x3f, 0x00, 0x80, 
  0xff, 0x7f, 0xfe, 0xff, 0x3f, 0x00, 0x00, 0xff, 0x7f, 0xfc, 0xff, 0x3f, 0x00, 0x00, 0xfc, 0x7f, 
  0xfc, 0xff, 0x1f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xff, 0x1f, 0x00, 0x00, 0x80, 0x7f, 0xfc, 0xff, 
  0x0f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xff, 0x07, 0x00, 0x00, 0x80, 0xff, 0xff, 0x7f, 0x00, 0x00, 
  0x00, 0x80, 0x7f, 0xff, 0xff, 0x00, 0x00, 0x00, 0x80, 0x7f, 0xfc, 0xff, 0x01, 0x00, 0x00, 0x80, 
  0x7f, 0xfc, 0xff, 0x01, 0x00, 0x00, 0x80, 0x7f, 0xfc, 0xff, 0x03, 0x00, 0x00, 0x80, 0x7f, 0xfc, 
  0xff, 0x03, 0x00, 0x00, 0x80, 0x7f, 0xfc, 0xff, 0x03, 0x00, 0x00, 0x80, 0x7f, 0xf8, 0xff, 0x03, 
  0x00, 0x00, 0x80, 0x7f, 0xf8, 0xff, 0x03, 0x00
};
// 'frame_20_delay-0', 56x56px
const unsigned char rick_roll_frame_20_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xff, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xff, 0x01, 0x00, 
  0x00, 0x00, 0x00, 0xc0, 0xff, 0x01, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x00, 0x01, 0x00, 0x00, 0x00, 
  0x00, 0x40, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x40, 
  0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x80, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x80, 
  0x01, 0x00, 0x00, 0x00, 0x00, 0x60, 0x80, 0x03, 0x00, 0x00, 0x00, 0x00, 0x78, 0x41, 0x0f, 0x00, 
  0x00, 0x00, 0x00, 0x7e, 0x00, 0x7f, 0x00, 0x00, 0x00, 0x80, 0x7f, 0x20, 0xff, 0x01, 0x00, 0x00, 
  0xc0, 0x7f, 0x10, 0xff, 0x03, 0x00, 0x00, 0xe0, 0x7f, 0x9c, 0xff, 0x07, 0x00, 0x00, 0xe0, 0xff, 
  0xf1, 0xff, 0x07, 0x00, 0x00, 0xf0, 0xff, 0xc1, 0xff, 0x07, 0x00, 0x00, 0xf0, 0xff, 0xc7, 0xff, 
  0x07, 0x00, 0x00, 0xf0, 0xff, 0xc1, 0xff, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xe1, 0xff, 0x0f, 0x00, 
  0x00, 0xf0, 0xff, 0xe1, 0xf9, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xff, 0xe3, 0x0f, 0x00, 0x00, 0xf0, 
  0xff, 0xff, 0xc1, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xe3, 0xc1, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xe3, 
  0xc1, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xe3, 0xc7, 0x07, 0x00, 0x00, 0xf0, 0xff, 0xf3, 0xc3, 0x0f, 
  0x00, 0x00, 0xf0, 0xff, 0xfb, 0xc3, 0x0f, 0x00, 0x00, 0xf8, 0xff, 0xff, 0xc7, 0x1f, 0x00, 0x00, 
  0xf8, 0xff, 0xeb, 0xff, 0x3f, 0x00, 0x00, 0x38, 0xff, 0xe3, 0xff, 0x3f, 0x00, 0x00, 0x68, 0xff, 
  0xe3, 0xff, 0x1f, 0x00, 0x00, 0x40, 0xff, 0xe3, 0xff, 0x0f, 0x00, 0x00, 0x60, 0xff, 0xff, 0xff, 
  0x0f, 0x00, 0x00, 0x20, 0xff, 0xef, 0xff, 0x07, 0x00, 0x00, 0x00, 0xff, 0xeb, 0xff, 0x03, 0x00, 
  0x00, 0xc0, 0xff, 0xff, 0x3f, 0x00, 0x00, 0x00, 0xe0, 0xff, 0xdb, 0x3f, 0x00, 0x00, 0x00, 0xc0, 
  0xff, 0xc3, 0x3f, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x83, 0x3f, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x83, 
  0x3f, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x83, 0x3f, 0x00, 0x00, 0x00, 0xe0, 0xff, 0x03, 0x3f, 0x00, 
  0x00, 0x00, 0xe0, 0xff, 0x03, 0x3f, 0x00, 0x00
};
// 'frame_21_delay-0', 56x56px
const unsigned char rick_roll_frame_21_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xff, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xff, 0x01, 0x00, 
  0x00, 0x00, 0x00, 0xc0, 0xff, 0x01, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x00, 0x01, 0x00, 0x00, 0x00, 
  0x00, 0x40, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x40, 
  0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x80, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x80, 
  0x01, 0x00, 0x00, 0x00, 0x00, 0x60, 0x80, 0x03, 0x00, 0x00, 0x00, 0x00, 0x78, 0x41, 0x0f, 0x00, 
  0x00, 0x00, 0x00, 0x7e, 0x00, 0x7f, 0x00, 0x00, 0x00, 0x80, 0x7f, 0x20, 0xff, 0x01, 0x00, 0x00, 
  0xc0, 0x7f, 0x10, 0xff, 0x03, 0x00, 0x00, 0xe0, 0x7f, 0x9c, 0xff, 0x07, 0x00, 0x00, 0xe0, 0xff, 
  0xf1, 0xff, 0x07, 0x00, 0x00, 0xf0, 0xff, 0xc1, 0xff, 0x07, 0x00, 0x00, 0xf0, 0xff, 0xc7, 0xff, 
  0x07, 0x00, 0x00, 0xf0, 0xff, 0xc1, 0xff, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xe1, 0xff, 0x0f, 0x00, 
  0x00, 0xf0, 0xff, 0xe1, 0xf9, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xff, 0xe3, 0x0f, 0x00, 0x00, 0xf0, 
  0xff, 0xff, 0xc1, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xe3, 0xc1, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xe3, 
  0xc1, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xe3, 0xc7, 0x07, 0x00, 0x00, 0xf0, 0xff, 0xf3, 0xc3, 0x0f, 
  0x00, 0x00, 0xf0, 0xff, 0xfb, 0xc3, 0x0f, 0x00, 0x00, 0xf8, 0xff, 0xff, 0xc7, 0x1f, 0x00, 0x00, 
  0xf8, 0xff, 0xeb, 0xff, 0x3f, 0x00, 0x00, 0x38, 0xff, 0xe3, 0xff, 0x3f, 0x00, 0x00, 0x68, 0xff, 
  0xe3, 0xff, 0x1f, 0x00, 0x00, 0x40, 0xff, 0xe3, 0xff, 0x0f, 0x00, 0x00, 0x60, 0xff, 0xff, 0xff, 
  0x0f, 0x00, 0x00, 0x20, 0xff, 0xef, 0xff, 0x07, 0x00, 0x00, 0x00, 0xff, 0xeb, 0xff, 0x03, 0x00, 
  0x00, 0xc0, 0xff, 0xff, 0x3f, 0x00, 0x00, 0x00, 0xe0, 0xff, 0xdb, 0x3f, 0x00, 0x00, 0x00, 0xc0, 
  0xff, 0xc3, 0x3f, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x83, 0x3f, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x83, 
  0x3f, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x83, 0x3f, 0x00, 0x00, 0x00, 0xe0, 0xff, 0x03, 0x3f, 0x00, 
  0x00, 0x00, 0xe0, 0xff, 0x03, 0x3f, 0x00, 0x00
};
// 'frame_22_delay-0', 56x56px
const unsigned char rick_roll_frame_22_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xff, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x80, 0xff, 0x01, 0x00, 0x00, 0x00, 0x00, 0x80, 0xff, 0x01, 0x00, 0x00, 0x00, 
  0x00, 0x80, 0xc0, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x80, 0x03, 0x00, 0x00, 0x00, 0x00, 0x40, 0x80, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x01, 
  0x00, 0x00, 0x00, 0x00, 0x40, 0x80, 0x01, 0x00, 0x00, 0x00, 0x00, 0x40, 0x80, 0x01, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x80, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x70, 0x00, 0x03, 0x00, 0x00, 0x00, 0x00, 0x7c, 0x40, 0x0f, 0x00, 0x00, 0x00, 
  0x00, 0x7f, 0x01, 0x7f, 0x00, 0x00, 0x00, 0xc0, 0x7f, 0x20, 0xff, 0x03, 0x00, 0x00, 0xe0, 0x7f, 
  0x10, 0xff, 0x03, 0x00, 0x00, 0xf0, 0x7f, 0x8c, 0xff, 0x07, 0x00, 0x00, 0xf0, 0xff, 0xff, 0xff, 
  0x07, 0x00, 0x00, 0xf0, 0xff, 0xff, 0xff, 0x07, 0x00, 0x00, 0xf0, 0xff, 0xff, 0xff, 0x0f, 0x00, 
  0x00, 0xf0, 0xff, 0xff, 0xff, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xff, 0xff, 0x0f, 0x00, 0x00, 0xf0, 
  0xff, 0xff, 0xff, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xdf, 0xff, 0x07, 0x00, 0x00, 0xf0, 0xe7, 0xff, 
  0xdf, 0x07, 0x00, 0x00, 0xf0, 0xe1, 0xc3, 0xbf, 0x07, 0x00, 0x00, 0xf8, 0xf3, 0xf7, 0x1f, 0x06, 
  0x00, 0x00, 0xf8, 0xe5, 0xc7, 0x1f, 0x0c, 0x00, 0x00, 0xf8, 0xe9, 0xc7, 0x1f, 0x0c, 0x00, 0x00, 
  0xf8, 0xf1, 0x87, 0x1f, 0x1e, 0x00, 0x00, 0xf8, 0xf1, 0x87, 0x1f, 0x3e, 0x00, 0x00, 0xf8, 0xf1, 
  0xcf, 0x3f, 0x3f, 0x00, 0x00, 0xf8, 0xff, 0x8f, 0x7f, 0x3f, 0x00, 0x00, 0xf8, 0xff, 0xdf, 0xff, 
  0x3f, 0x00, 0x00, 0xf8, 0xff, 0x7f, 0xff, 0x1f, 0x00, 0x00, 0xf8, 0xff, 0xdf, 0xff, 0x1f, 0x00, 
  0x00, 0xf0, 0xff, 0x1f, 0xfe, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xdf, 0xff, 0x07, 0x00, 0x00, 0x00, 
  0xfe, 0xdf, 0xff, 0x00, 0x00, 0x00, 0x00, 0xff, 0xdf, 0xf9, 0x00, 0x00, 0x00, 0x00, 0xff, 0x1f, 
  0xf8, 0x01, 0x00, 0x00, 0x00, 0xff, 0x1f, 0xf0, 0x01, 0x00, 0x00, 0x00, 0xff, 0x1f, 0xf0, 0x03, 
  0x00, 0x00, 0x80, 0xff, 0x1f, 0xe0, 0x03, 0x00
};
// 'frame_23_delay-0', 56x56px
const unsigned char rick_roll_frame_23_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 
  0x0f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x1f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0x3f, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0xfc, 0x3f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x38, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x04, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0xd3, 
  0x04, 0x00, 0x00, 0x00, 0x00, 0x80, 0x07, 0x04, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x07, 0x1c, 0x00, 
  0x00, 0x00, 0x00, 0xf8, 0x03, 0x3a, 0x00, 0x00, 0x00, 0x00, 0xff, 0x0b, 0xf8, 0x00, 0x00, 0x00, 
  0x80, 0xff, 0x03, 0xf9, 0x03, 0x00, 0x00, 0xc0, 0xff, 0x83, 0xf8, 0x07, 0x00, 0x00, 0xc0, 0xff, 
  0x63, 0xf8, 0x1f, 0x00, 0x00, 0xe0, 0xff, 0x7f, 0xf8, 0x3f, 0x00, 0x00, 0xe0, 0xff, 0x0f, 0xff, 
  0x3f, 0x00, 0x00, 0xe0, 0xff, 0xdf, 0xfd, 0x3f, 0x00, 0x00, 0xe0, 0xff, 0xdf, 0xfd, 0x3f, 0x00, 
  0x00, 0xe0, 0xff, 0x9f, 0xfd, 0x3f, 0x00, 0x00, 0xe0, 0xff, 0x7f, 0xfc, 0x3f, 0x00, 0x00, 0xf0, 
  0xff, 0x19, 0xfe, 0x3f, 0x00, 0x00, 0xf0, 0x7f, 0x1c, 0xff, 0x3f, 0x00, 0x00, 0xf8, 0x3f, 0x78, 
  0xfc, 0x3f, 0x00, 0x00, 0xf8, 0x3f, 0x3e, 0xfe, 0x3f, 0x00, 0x00, 0xf8, 0x3f, 0x3c, 0xfe, 0x3f, 
  0x00, 0x00, 0xfc, 0x3f, 0xb8, 0xff, 0x3f, 0x00, 0x00, 0xfc, 0x3f, 0xfe, 0xfc, 0x3f, 0x00, 0x00, 
  0xfc, 0x3f, 0x7e, 0xfc, 0x7f, 0x00, 0x00, 0xfc, 0x3f, 0x3f, 0xfc, 0x7f, 0x00, 0x00, 0xfc, 0xff, 
  0x7f, 0xfd, 0x7f, 0x00, 0x00, 0xfc, 0xff, 0x7f, 0xfc, 0x7f, 0x00, 0x00, 0xfc, 0xff, 0x7f, 0xfc, 
  0x7f, 0x08, 0x00, 0xfc, 0xff, 0x7f, 0xf8, 0x3f, 0x0a, 0x00, 0xf8, 0xff, 0xff, 0xf8, 0x3f, 0x08, 
  0x00, 0xf0, 0xff, 0xff, 0xf9, 0x3f, 0x06, 0x00, 0xf0, 0xff, 0xff, 0xf7, 0x7f, 0x04, 0x00, 0x00, 
  0xfc, 0xff, 0xf3, 0xff, 0x03, 0x00, 0x00, 0xfc, 0xff, 0xfb, 0xff, 0x03, 0x00, 0x00, 0xfe, 0xff, 
  0xe0, 0xff, 0x01, 0x00, 0x00, 0xfe, 0xff, 0xc0, 0x1f, 0x00, 0x00, 0x00, 0xfe, 0xff, 0xc0, 0x07, 
  0x00, 0x00, 0x00, 0xfe, 0xff, 0xc0, 0x0f, 0x00
};
// 'frame_24_delay-0', 56x56px
const unsigned char rick_roll_frame_24_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 
  0x0f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x1f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0x3f, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0xfc, 0x3f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x38, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x04, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0xd3, 
  0x04, 0x00, 0x00, 0x00, 0x00, 0x80, 0x07, 0x04, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x07, 0x1c, 0x00, 
  0x00, 0x00, 0x00, 0xf8, 0x03, 0x3a, 0x00, 0x00, 0x00, 0x00, 0xff, 0x0b, 0xf8, 0x00, 0x00, 0x00, 
  0x80, 0xff, 0x03, 0xf9, 0x03, 0x00, 0x00, 0xc0, 0xff, 0x83, 0xf8, 0x07, 0x00, 0x00, 0xc0, 0xff, 
  0x63, 0xf8, 0x1f, 0x00, 0x00, 0xe0, 0xff, 0x7f, 0xf8, 0x3f, 0x00, 0x00, 0xe0, 0xff, 0x0f, 0xff, 
  0x3f, 0x00, 0x00, 0xe0, 0xff, 0xdf, 0xfd, 0x3f, 0x00, 0x00, 0xe0, 0xff, 0xdf, 0xfd, 0x3f, 0x00, 
  0x00, 0xe0, 0xff, 0x9f, 0xfd, 0x3f, 0x00, 0x00, 0xe0, 0xff, 0x7f, 0xfc, 0x3f, 0x00, 0x00, 0xf0, 
  0xff, 0x19, 0xfe, 0x3f, 0x00, 0x00, 0xf0, 0x7f, 0x1c, 0xff, 0x3f, 0x00, 0x00, 0xf8, 0x3f, 0x78, 
  0xfc, 0x3f, 0x00, 0x00, 0xf8, 0x3f, 0x3e, 0xfe, 0x3f, 0x00, 0x00, 0xf8, 0x3f, 0x3c, 0xfe, 0x3f, 
  0x00, 0x00, 0xfc, 0x3f, 0xb8, 0xff, 0x3f, 0x00, 0x00, 0xfc, 0x3f, 0xfe, 0xfc, 0x3f, 0x00, 0x00, 
  0xfc, 0x3f, 0x7e, 0xfc, 0x7f, 0x00, 0x00, 0xfc, 0x3f, 0x3f, 0xfc, 0x7f, 0x00, 0x00, 0xfc, 0xff, 
  0x7f, 0xfd, 0x7f, 0x00, 0x00, 0xfc, 0xff, 0x7f, 0xfc, 0x7f, 0x00, 0x00, 0xfc, 0xff, 0x7f, 0xfc, 
  0x7f, 0x08, 0x00, 0xfc, 0xff, 0x7f, 0xf8, 0x3f, 0x0a, 0x00, 0xf8, 0xff, 0xff, 0xf8, 0x3f, 0x08, 
  0x00, 0xf0, 0xff, 0xff, 0xf9, 0x3f, 0x06, 0x00, 0xf0, 0xff, 0xff, 0xf7, 0x7f, 0x04, 0x00, 0x00, 
  0xfc, 0xff, 0xf3, 0xff, 0x03, 0x00, 0x00, 0xfc, 0xff, 0xfb, 0xff, 0x03, 0x00, 0x00, 0xfe, 0xff, 
  0xe0, 0xff, 0x01, 0x00, 0x00, 0xfe, 0xff, 0xc0, 0x1f, 0x00, 0x00, 0x00, 0xfe, 0xff, 0xc0, 0x07, 
  0x00, 0x00, 0x00, 0xfe, 0xff, 0xc0, 0x0f, 0x00
};
// 'frame_25_delay-0', 56x56px
const unsigned char rick_roll_frame_25_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfc, 
  0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfe, 0x03, 0x00, 0x00, 0x00, 0x00, 0x80, 0xff, 0x03, 0x00, 
  0x00, 0x00, 0x00, 0x80, 0xff, 0x03, 0x00, 0x00, 0x00, 0x00, 0x80, 0x1f, 0x02, 0x00, 0x00, 0x00, 
  0x00, 0xc0, 0x0f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x0f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 
  0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x04, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x01, 0x02, 0x00, 0x00, 
  0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0xc0, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 0x40, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x7e, 0xc1, 0x03, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x82, 0x0f, 0x00, 
  0x00, 0x00, 0xe0, 0xff, 0x20, 0x3f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x80, 0x7f, 0x00, 0x00, 0x00, 
  0xf0, 0xff, 0xbd, 0xff, 0x00, 0x00, 0x00, 0xf0, 0xff, 0xe3, 0xff, 0x00, 0x00, 0x00, 0xf8, 0xff, 
  0xff, 0xff, 0x00, 0x00, 0x00, 0xf8, 0xff, 0xff, 0xff, 0x00, 0x00, 0x00, 0xf8, 0xff, 0xff, 0xff, 
  0x00, 0x00, 0x00, 0xf8, 0xff, 0xf7, 0xff, 0x00, 0x00, 0x00, 0xfc, 0xff, 0xff, 0xff, 0x01, 0x00, 
  0x00, 0xfc, 0xff, 0xff, 0xff, 0x01, 0x00, 0x00, 0xfc, 0xff, 0xcf, 0xff, 0x01, 0x00, 0x00, 0xfe, 
  0xff, 0xff, 0xff, 0x01, 0x00, 0x00, 0xfe, 0xff, 0x0f, 0xff, 0x01, 0x00, 0x00, 0xfe, 0xff, 0x83, 
  0xff, 0x01, 0x00, 0x00, 0xfe, 0xff, 0xc1, 0xff, 0x01, 0x00, 0x00, 0xfe, 0xff, 0x83, 0xff, 0x01, 
  0x00, 0x00, 0xfe, 0xff, 0xc3, 0xff, 0x03, 0x00, 0x00, 0xfe, 0xff, 0xe3, 0xff, 0x0f, 0x01, 0x00, 
  0xfe, 0xff, 0xff, 0xff, 0x7f, 0x01, 0x00, 0xfe, 0xff, 0xff, 0xff, 0x1f, 0x18, 0x00, 0xfc, 0xff, 
  0xff, 0xff, 0x1f, 0x78, 0x00, 0xf8, 0xff, 0xbf, 0xff, 0x1f, 0x10, 0x00, 0x80, 0xff, 0xff, 0xff, 
  0x3f, 0x78, 0x00, 0x80, 0xff, 0xff, 0x3f, 0x7c, 0x1d, 0x00, 0x80, 0xff, 0xbf, 0x3f, 0xc0, 0x14, 
  0x00, 0x80, 0xff, 0x3f, 0x3f, 0x00, 0x00, 0x00, 0x80, 0xff, 0x3f, 0x3f, 0x00, 0x00, 0x00, 0x80, 
  0xff, 0x3f, 0x3f, 0x00, 0x00, 0x00, 0x80, 0xff, 0x3f, 0x3e, 0x00, 0x00, 0x00, 0x80, 0xff, 0x3f, 
  0x3e, 0x00, 0x00, 0x00, 0x80, 0xff, 0x3f, 0x3c, 0x00, 0x00, 0x00, 0x80, 0xff, 0x3f, 0x3c, 0x00, 
  0x00, 0x00, 0x80, 0xff, 0x7f, 0x38, 0x00, 0x00
};
// 'frame_26_delay-0', 56x56px
const unsigned char rick_roll_frame_26_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfc, 
  0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfe, 0x03, 0x00, 0x00, 0x00, 0x00, 0x80, 0xff, 0x03, 0x00, 
  0x00, 0x00, 0x00, 0x80, 0xff, 0x03, 0x00, 0x00, 0x00, 0x00, 0x80, 0x1f, 0x02, 0x00, 0x00, 0x00, 
  0x00, 0xc0, 0x0f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x0f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 
  0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x04, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x01, 0x02, 0x00, 0x00, 
  0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0xc0, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 0x40, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x7e, 0xc1, 0x03, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x82, 0x0f, 0x00, 
  0x00, 0x00, 0xe0, 0xff, 0x20, 0x3f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x80, 0x7f, 0x00, 0x00, 0x00, 
  0xf0, 0xff, 0xbd, 0xff, 0x00, 0x00, 0x00, 0xf0, 0xff, 0xe3, 0xff, 0x00, 0x00, 0x00, 0xf8, 0xff, 
  0xff, 0xff, 0x00, 0x00, 0x00, 0xf8, 0xff, 0xff, 0xff, 0x00, 0x00, 0x00, 0xf8, 0xff, 0xff, 0xff, 
  0x00, 0x00, 0x00, 0xf8, 0xff, 0xf7, 0xff, 0x00, 0x00, 0x00, 0xfc, 0xff, 0xff, 0xff, 0x01, 0x00, 
  0x00, 0xfc, 0xff, 0xff, 0xff, 0x01, 0x00, 0x00, 0xfc, 0xff, 0xcf, 0xff, 0x01, 0x00, 0x00, 0xfe, 
  0xff, 0xff, 0xff, 0x01, 0x00, 0x00, 0xfe, 0xff, 0x0f, 0xff, 0x01, 0x00, 0x00, 0xfe, 0xff, 0x83, 
  0xff, 0x01, 0x00, 0x00, 0xfe, 0xff, 0xc1, 0xff, 0x01, 0x00, 0x00, 0xfe, 0xff, 0x83, 0xff, 0x01, 
  0x00, 0x00, 0xfe, 0xff, 0xc3, 0xff, 0x03, 0x00, 0x00, 0xfe, 0xff, 0xe3, 0xff, 0x0f, 0x01, 0x00, 
  0xfe, 0xff, 0xff, 0xff, 0x7f, 0x01, 0x00, 0xfe, 0xff, 0xff, 0xff, 0x1f, 0x18, 0x00, 0xfc, 0xff, 
  0xff, 0xff, 0x1f, 0x78, 0x00, 0xf8, 0xff, 0xbf, 0xff, 0x1f, 0x10, 0x00, 0x80, 0xff, 0xff, 0xff, 
  0x3f, 0x78, 0x00, 0x80, 0xff, 0xff, 0x3f, 0x7c, 0x1d, 0x00, 0x80, 0xff, 0xbf, 0x3f, 0xc0, 0x14, 
  0x00, 0x80, 0xff, 0x3f, 0x3f, 0x00, 0x00, 0x00, 0x80, 0xff, 0x3f, 0x3f, 0x00, 0x00, 0x00, 0x80, 
  0xff, 0x3f, 0x3f, 0x00, 0x00, 0x00, 0x80, 0xff, 0x3f, 0x3e, 0x00, 0x00, 0x00, 0x80, 0xff, 0x3f, 
  0x3e, 0x00, 0x00, 0x00, 0x80, 0xff, 0x3f, 0x3c, 0x00, 0x00, 0x00, 0x80, 0xff, 0x3f, 0x3c, 0x00, 
  0x00, 0x00, 0x80, 0xff, 0x7f, 0x38, 0x00, 0x00
};
// 'frame_27_delay-0', 56x56px
const unsigned char rick_roll_frame_27_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x3f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x7f, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0x7f, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0xf8, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x78, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 
  0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x60, 0x40, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x30, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x38, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1c, 0xf0, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x1f, 0xe0, 0x03, 0x00, 0x00, 0x00, 0xc0, 0x1f, 0xe0, 0x0f, 0x00, 
  0x00, 0x00, 0xf0, 0x9f, 0xc0, 0x1f, 0x00, 0x00, 0x00, 0xfc, 0x1f, 0xe5, 0x3f, 0x00, 0x00, 0x00, 
  0xfe, 0x3f, 0xe3, 0x3f, 0x00, 0x00, 0x00, 0xfe, 0xff, 0xff, 0x7f, 0x00, 0x00, 0x00, 0xfe, 0xff, 
  0xf0, 0x7f, 0x00, 0x00, 0x00, 0xfe, 0xff, 0xf1, 0x7f, 0x00, 0x00, 0x00, 0xff, 0xff, 0xfb, 0x7f, 
  0x00, 0x00, 0x00, 0xff, 0xff, 0xf0, 0x7f, 0x00, 0x00, 0x00, 0xff, 0xff, 0xff, 0x7f, 0x00, 0x00, 
  0x00, 0xff, 0xff, 0xff, 0x7f, 0x00, 0x00, 0x00, 0xff, 0xff, 0xfd, 0x7f, 0x00, 0x00, 0x00, 0xff, 
  0xff, 0xf3, 0x7f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xf3, 0x7f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xf3, 
  0x7f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xf3, 0x6f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xff, 0x87, 0x00, 
  0x00, 0x80, 0xff, 0xff, 0xf7, 0x2f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xff, 0x0f, 0x00, 0x00, 0xc0, 
  0xff, 0xff, 0xff, 0x8f, 0x00, 0x00, 0xc0, 0xff, 0x7f, 0xfe, 0x8f, 0x00, 0x00, 0x80, 0xff, 0x9f, 
  0xf7, 0x1f, 0x00, 0x00, 0x00, 0xff, 0x4f, 0xec, 0xff, 0x00, 0x00, 0x00, 0xff, 0x87, 0xed, 0x7f, 
  0x00, 0x00, 0x00, 0xfe, 0x07, 0xff, 0x7f, 0x00, 0x00, 0x00, 0xfc, 0x07, 0xfe, 0x07, 0x00, 0x00, 
  0x00, 0xf0, 0x07, 0xcf, 0x0f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0xcf, 0x0f, 0x00, 0x00, 0x00, 0xf0, 
  0xff, 0xcf, 0x0f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 0x0f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 
  0x1f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 0x1f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 0x1f, 0x00, 
  0x00, 0x00, 0xf0, 0xff, 0x0f, 0x1f, 0x00, 0x00
};
// 'frame_28_delay-0', 56x56px
const unsigned char rick_roll_frame_28_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x3f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x7f, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0x7f, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0xf8, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x78, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 
  0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x60, 0x40, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x30, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x38, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1c, 0xf0, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x1f, 0xe0, 0x03, 0x00, 0x00, 0x00, 0xc0, 0x1f, 0xe0, 0x0f, 0x00, 
  0x00, 0x00, 0xf0, 0x9f, 0xc0, 0x1f, 0x00, 0x00, 0x00, 0xfc, 0x1f, 0xe5, 0x3f, 0x00, 0x00, 0x00, 
  0xfe, 0x3f, 0xe3, 0x3f, 0x00, 0x00, 0x00, 0xfe, 0xff, 0xff, 0x7f, 0x00, 0x00, 0x00, 0xfe, 0xff, 
  0xf0, 0x7f, 0x00, 0x00, 0x00, 0xfe, 0xff, 0xf1, 0x7f, 0x00, 0x00, 0x00, 0xff, 0xff, 0xfb, 0x7f, 
  0x00, 0x00, 0x00, 0xff, 0xff, 0xf0, 0x7f, 0x00, 0x00, 0x00, 0xff, 0xff, 0xff, 0x7f, 0x00, 0x00, 
  0x00, 0xff, 0xff, 0xff, 0x7f, 0x00, 0x00, 0x00, 0xff, 0xff, 0xfd, 0x7f, 0x00, 0x00, 0x00, 0xff, 
  0xff, 0xf3, 0x7f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xf3, 0x7f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xf3, 
  0x7f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xf3, 0x6f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xff, 0x87, 0x00, 
  0x00, 0x80, 0xff, 0xff, 0xf7, 0x2f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xff, 0x0f, 0x00, 0x00, 0xc0, 
  0xff, 0xff, 0xff, 0x8f, 0x00, 0x00, 0xc0, 0xff, 0x7f, 0xfe, 0x8f, 0x00, 0x00, 0x80, 0xff, 0x9f, 
  0xf7, 0x1f, 0x00, 0x00, 0x00, 0xff, 0x4f, 0xec, 0xff, 0x00, 0x00, 0x00, 0xff, 0x87, 0xed, 0x7f, 
  0x00, 0x00, 0x00, 0xfe, 0x07, 0xff, 0x7f, 0x00, 0x00, 0x00, 0xfc, 0x07, 0xfe, 0x07, 0x00, 0x00, 
  0x00, 0xf0, 0x07, 0xcf, 0x0f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0xcf, 0x0f, 0x00, 0x00, 0x00, 0xf0, 
  0xff, 0xcf, 0x0f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 0x0f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 
  0x1f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 0x1f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 0x1f, 0x00, 
  0x00, 0x00, 0xf0, 0xff, 0x0f, 0x1f, 0x00, 0x00
};
// 'frame_29_delay-0', 56x56px
const unsigned char rick_roll_frame_29_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x3f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x7f, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0x7f, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0xf8, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x78, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 
  0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x60, 0x40, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x30, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x38, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1c, 0xf0, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x1f, 0xe0, 0x03, 0x00, 0x00, 0x00, 0xc0, 0x1f, 0xe0, 0x0f, 0x00, 
  0x00, 0x00, 0xf0, 0x9f, 0xc0, 0x1f, 0x00, 0x00, 0x00, 0xfc, 0x1f, 0xe5, 0x3f, 0x00, 0x00, 0x00, 
  0xfe, 0x3f, 0xe3, 0x3f, 0x00, 0x00, 0x00, 0xfe, 0xff, 0xff, 0x7f, 0x00, 0x00, 0x00, 0xfe, 0xff, 
  0xf0, 0x7f, 0x00, 0x00, 0x00, 0xfe, 0xff, 0xf1, 0x7f, 0x00, 0x00, 0x00, 0xff, 0xff, 0xfb, 0x7f, 
  0x00, 0x00, 0x00, 0xff, 0xff, 0xf0, 0x7f, 0x00, 0x00, 0x00, 0xff, 0xff, 0xff, 0x7f, 0x00, 0x00, 
  0x00, 0xff, 0xff, 0xff, 0x7f, 0x00, 0x00, 0x00, 0xff, 0xff, 0xfd, 0x7f, 0x00, 0x00, 0x00, 0xff, 
  0xff, 0xf3, 0x7f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xf3, 0x7f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xf3, 
  0x7f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xf3, 0x6f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xff, 0x87, 0x00, 
  0x00, 0x80, 0xff, 0xff, 0xf7, 0x2f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xff, 0x0f, 0x00, 0x00, 0xc0, 
  0xff, 0xff, 0xff, 0x8f, 0x00, 0x00, 0xc0, 0xff, 0x7f, 0xfe, 0x8f, 0x00, 0x00, 0x80, 0xff, 0x9f, 
  0xf7, 0x1f, 0x00, 0x00, 0x00, 0xff, 0x4f, 0xec, 0xff, 0x00, 0x00, 0x00, 0xff, 0x87, 0xed, 0x7f, 
  0x00, 0x00, 0x00, 0xfe, 0x07, 0xff, 0x7f, 0x00, 0x00, 0x00, 0xfc, 0x07, 0xfe, 0x07, 0x00, 0x00, 
  0x00, 0xf0, 0x07, 0xcf, 0x0f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0xcf, 0x0f, 0x00, 0x00, 0x00, 0xf0, 
  0xff, 0xcf, 0x0f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 0x0f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 
  0x1f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 0x1f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 0x1f, 0x00, 
  0x00, 0x00, 0xf0, 0xff, 0x0f, 0x1f, 0x00, 0x00
};
// 'frame_30_delay-0', 56x56px
const unsigned char rick_roll_frame_30_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x1f, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x7f, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0xf0, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x60, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x10, 0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 
  0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x80, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x20, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc2, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x20, 0x80, 0x07, 0x00, 0x00, 0x00, 0x00, 0x70, 0x00, 0x7f, 0x00, 
  0x00, 0x00, 0x00, 0x7c, 0x00, 0xff, 0x01, 0x00, 0x00, 0x00, 0xbf, 0x20, 0xff, 0x07, 0x00, 0x00, 
  0xc0, 0x3f, 0x01, 0xff, 0x07, 0x00, 0x00, 0xf0, 0x3f, 0x12, 0xff, 0x07, 0x00, 0x00, 0xf0, 0x3f, 
  0x0c, 0xff, 0x07, 0x00, 0x00, 0xf8, 0x7f, 0xf7, 0xff, 0x07, 0x00, 0x00, 0xf8, 0xff, 0x81, 0xff, 
  0x07, 0x00, 0x00, 0xf8, 0xff, 0x80, 0xff, 0x0f, 0x00, 0x00, 0xf8, 0xff, 0x83, 0xff, 0x0f, 0x00, 
  0x00, 0xf8, 0xff, 0x81, 0xff, 0x0f, 0x00, 0x00, 0xf8, 0xff, 0xff, 0xff, 0x0f, 0x00, 0x00, 0xf8, 
  0xff, 0xc3, 0xff, 0x0f, 0x00, 0x00, 0xf8, 0xff, 0x83, 0xff, 0x1f, 0x00, 0x00, 0xf8, 0xff, 0x83, 
  0xff, 0x1f, 0x00, 0x00, 0xf8, 0xff, 0x87, 0xff, 0x1f, 0x00, 0x00, 0xf8, 0xff, 0x87, 0xff, 0x1f, 
  0x00, 0x00, 0xf8, 0xff, 0x87, 0x3f, 0x3e, 0x00, 0x00, 0xf8, 0xff, 0x87, 0x7f, 0x7c, 0x00, 0x00, 
  0xf8, 0xff, 0xff, 0x3f, 0x38, 0x00, 0x00, 0xec, 0xff, 0x87, 0x1f, 0x18, 0x00, 0x00, 0x98, 0xff, 
  0x07, 0x7f, 0x1c, 0x00, 0x00, 0x60, 0xff, 0x7f, 0x7f, 0x1c, 0x00, 0x00, 0xcc, 0xfe, 0x1f, 0xff, 
  0x0f, 0x00, 0x00, 0x08, 0xfe, 0xff, 0xfe, 0x03, 0x00, 0x00, 0xd8, 0xff, 0x0f, 0xfe, 0x01, 0x00, 
  0x00, 0x98, 0xff, 0x3f, 0x7e, 0x00, 0x00, 0x00, 0xd8, 0xff, 0xbf, 0x7f, 0x00, 0x00, 0x00, 0xf0, 
  0xff, 0xbf, 0xff, 0x00, 0x00, 0x00, 0x80, 0xff, 0x0f, 0xf8, 0x00, 0x00, 0x00, 0x80, 0xff, 0x0f, 
  0xf8, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x0f, 0xf0, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x0f, 0xf0, 0x00, 
  0x00, 0x00, 0xc0, 0xff, 0x0f, 0xe0, 0x01, 0x00
};
// 'frame_31_delay-0', 56x56px
const unsigned char rick_roll_frame_31_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0xf8, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfe, 
  0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0xcf, 0x0e, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x03, 0x0c, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0x04, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x03, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x04, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x02, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x1e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 
  0xff, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x85, 0xfe, 0x03, 0x00, 0x00, 0x00, 0xf0, 0x41, 0xfe, 0x1f, 
  0x00, 0x00, 0x00, 0xf8, 0x09, 0xfe, 0x1f, 0x00, 0x00, 0x00, 0xfc, 0x1f, 0xff, 0x1f, 0x00, 0x00, 
  0x00, 0xfe, 0xef, 0xff, 0x1f, 0x00, 0x00, 0x00, 0xfe, 0xe7, 0xff, 0x1f, 0x00, 0x00, 0x00, 0xfe, 
  0x87, 0xff, 0x1f, 0x00, 0x00, 0x00, 0xfe, 0xc7, 0xff, 0x3f, 0x00, 0x00, 0x00, 0xfe, 0xc7, 0xff, 
  0x3f, 0x00, 0x00, 0x00, 0xfe, 0xff, 0xf9, 0x3f, 0x00, 0x00, 0x00, 0xfe, 0xc7, 0xf5, 0x3f, 0x00, 
  0x00, 0x00, 0xfe, 0xc7, 0xf3, 0x3f, 0x00, 0x00, 0x00, 0xfe, 0xc7, 0xf1, 0x7f, 0x00, 0x00, 0x00, 
  0xfe, 0xe7, 0xe0, 0x7f, 0x00, 0x00, 0x00, 0xfe, 0xe7, 0xf3, 0xff, 0x00, 0x00, 0x00, 0xfe, 0xe7, 
  0xf1, 0xff, 0x00, 0x00, 0x00, 0xfe, 0xf7, 0xf3, 0xff, 0x01, 0x00, 0x00, 0xfe, 0xe7, 0xff, 0xff, 
  0x01, 0x00, 0x00, 0xfe, 0xff, 0xff, 0xff, 0x01, 0x00, 0x00, 0xfe, 0xe7, 0xff, 0xff, 0x00, 0x00, 
  0x00, 0xf0, 0xff, 0xff, 0x7f, 0x00, 0x00, 0x00, 0xf0, 0xe7, 0xff, 0x7f, 0x00, 0x00, 0xc0, 0xe1, 
  0xff, 0xff, 0x3f, 0x00, 0x00, 0x40, 0xf3, 0xe7, 0xff, 0x1f, 0x00, 0x00, 0x80, 0xf2, 0xff, 0xff, 
  0x07, 0x00, 0x00, 0x00, 0xf9, 0xf3, 0xff, 0x07, 0x00, 0x00, 0x00, 0xcc, 0xe3, 0xff, 0x07, 0x00, 
  0x00, 0x00, 0xc6, 0xe3, 0xff, 0x0f, 0x00, 0x00, 0x00, 0xe6, 0xe3, 0xff, 0x0f, 0x00, 0x00, 0x00, 
  0xe0, 0xe3, 0xff, 0x0f, 0x00, 0x00, 0x00, 0xe0, 0xe3, 0xff, 0x1f, 0x00, 0x00, 0x00, 0xe0, 0xe3, 
  0xff, 0x1f, 0x00, 0x00, 0x00, 0xf0, 0xc3, 0xff, 0x1f, 0x00, 0x00, 0x00, 0xf0, 0xc3, 0xff, 0x1f, 
  0x00, 0x00, 0x00, 0xf0, 0x81, 0xff, 0x1f, 0x00
};
// 'frame_32_delay-0', 56x56px
const unsigned char rick_roll_frame_32_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0xf8, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfe, 
  0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0xcf, 0x0e, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x03, 0x0c, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0x04, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x03, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x04, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x02, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x1e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 
  0xff, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x85, 0xfe, 0x03, 0x00, 0x00, 0x00, 0xf0, 0x41, 0xfe, 0x1f, 
  0x00, 0x00, 0x00, 0xf8, 0x09, 0xfe, 0x1f, 0x00, 0x00, 0x00, 0xfc, 0x1f, 0xff, 0x1f, 0x00, 0x00, 
  0x00, 0xfe, 0xef, 0xff, 0x1f, 0x00, 0x00, 0x00, 0xfe, 0xe7, 0xff, 0x1f, 0x00, 0x00, 0x00, 0xfe, 
  0x87, 0xff, 0x1f, 0x00, 0x00, 0x00, 0xfe, 0xc7, 0xff, 0x3f, 0x00, 0x00, 0x00, 0xfe, 0xc7, 0xff, 
  0x3f, 0x00, 0x00, 0x00, 0xfe, 0xff, 0xf9, 0x3f, 0x00, 0x00, 0x00, 0xfe, 0xc7, 0xf5, 0x3f, 0x00, 
  0x00, 0x00, 0xfe, 0xc7, 0xf3, 0x3f, 0x00, 0x00, 0x00, 0xfe, 0xc7, 0xf1, 0x7f, 0x00, 0x00, 0x00, 
  0xfe, 0xe7, 0xe0, 0x7f, 0x00, 0x00, 0x00, 0xfe, 0xe7, 0xf3, 0xff, 0x00, 0x00, 0x00, 0xfe, 0xe7, 
  0xf1, 0xff, 0x00, 0x00, 0x00, 0xfe, 0xf7, 0xf3, 0xff, 0x01, 0x00, 0x00, 0xfe, 0xe7, 0xff, 0xff, 
  0x01, 0x00, 0x00, 0xfe, 0xff, 0xff, 0xff, 0x01, 0x00, 0x00, 0xfe, 0xe7, 0xff, 0xff, 0x00, 0x00, 
  0x00, 0xf0, 0xff, 0xff, 0x7f, 0x00, 0x00, 0x00, 0xf0, 0xe7, 0xff, 0x7f, 0x00, 0x00, 0xc0, 0xe1, 
  0xff, 0xff, 0x3f, 0x00, 0x00, 0x40, 0xf3, 0xe7, 0xff, 0x1f, 0x00, 0x00, 0x80, 0xf2, 0xff, 0xff, 
  0x07, 0x00, 0x00, 0x00, 0xf9, 0xf3, 0xff, 0x07, 0x00, 0x00, 0x00, 0xcc, 0xe3, 0xff, 0x07, 0x00, 
  0x00, 0x00, 0xc6, 0xe3, 0xff, 0x0f, 0x00, 0x00, 0x00, 0xe6, 0xe3, 0xff, 0x0f, 0x00, 0x00, 0x00, 
  0xe0, 0xe3, 0xff, 0x0f, 0x00, 0x00, 0x00, 0xe0, 0xe3, 0xff, 0x1f, 0x00, 0x00, 0x00, 0xe0, 0xe3, 
  0xff, 0x1f, 0x00, 0x00, 0x00, 0xf0, 0xc3, 0xff, 0x1f, 0x00, 0x00, 0x00, 0xf0, 0xc3, 0xff, 0x1f, 
  0x00, 0x00, 0x00, 0xf0, 0x81, 0xff, 0x1f, 0x00
};
// 'frame_33_delay-0', 56x56px
const unsigned char rick_roll_frame_33_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0xff, 
  0x01, 0x00, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x01, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x81, 0x01, 0x00, 
  0x00, 0x00, 0x00, 0xc0, 0x00, 0x03, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x03, 0x00, 0x00, 0x00, 
  0x00, 0x40, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x60, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x38, 0xc0, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x3f, 0xe0, 0x03, 0x00, 0x00, 0x00, 0xe0, 0x1f, 0xd0, 0x0f, 0x00, 
  0x00, 0x00, 0xf0, 0x1f, 0xc8, 0x3f, 0x00, 0x00, 0x00, 0xf0, 0x1f, 0xc0, 0xff, 0x00, 0x00, 0x00, 
  0xf0, 0x3f, 0xe3, 0xe7, 0x01, 0x00, 0x00, 0xf8, 0x7f, 0xf0, 0xc7, 0x03, 0x00, 0x00, 0xf8, 0x7f, 
  0xff, 0x87, 0x03, 0x00, 0x00, 0xf8, 0x3f, 0xfe, 0x0f, 0x03, 0x00, 0x00, 0xfc, 0xff, 0xf7, 0x07, 
  0x03, 0x00, 0x00, 0xfc, 0x7f, 0xfe, 0x8f, 0x03, 0x00, 0x00, 0xfc, 0x7f, 0xf3, 0x8f, 0x03, 0x00, 
  0x00, 0xfe, 0xff, 0xf8, 0x8f, 0x03, 0x00, 0x00, 0xfe, 0x7f, 0xf8, 0x0f, 0x03, 0x00, 0x00, 0xff, 
  0x7f, 0xfe, 0x1f, 0x03, 0x00, 0x00, 0xff, 0x47, 0xfc, 0x3f, 0x07, 0x00, 0x80, 0xff, 0x43, 0xfc, 
  0xff, 0x07, 0x00, 0x80, 0xff, 0x61, 0xf8, 0xff, 0x07, 0x00, 0x80, 0xff, 0x01, 0xfe, 0xff, 0x0f, 
  0x00, 0x80, 0xff, 0x41, 0xfc, 0xff, 0x1f, 0x00, 0x80, 0xff, 0x71, 0xfe, 0xff, 0x3f, 0x00, 0x80, 
  0xff, 0x7f, 0xfe, 0xff, 0x3f, 0x00, 0x00, 0xff, 0x7f, 0xfc, 0xff, 0x3f, 0x00, 0x00, 0xfc, 0x7f, 
  0xfe, 0xff, 0x1f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xff, 0x1f, 0x00, 0x00, 0x80, 0x7f, 0xfc, 0xff, 
  0x0f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xff, 0x07, 0x00, 0x00, 0x80, 0xff, 0xff, 0x7f, 0x00, 0x00, 
  0x00, 0x80, 0x7f, 0xff, 0xff, 0x00, 0x00, 0x00, 0x80, 0x7f, 0xfc, 0xff, 0x01, 0x00, 0x00, 0x80, 
  0x7f, 0xfc, 0xff, 0x01, 0x00, 0x00, 0x80, 0x7f, 0xfc, 0xff, 0x03, 0x00, 0x00, 0x80, 0x7f, 0xfc, 
  0xff, 0x03, 0x00, 0x00, 0x80, 0x7f, 0xfc, 0xff, 0x03, 0x00, 0x00, 0x80, 0x7f, 0xf8, 0xff, 0x03, 
  0x00, 0x00, 0x80, 0x7f, 0xf8, 0xff, 0x03, 0x00
};
// 'frame_34_delay-0', 56x56px
const unsigned char rick_roll_frame_34_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0xff, 
  0x01, 0x00, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x01, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x81, 0x01, 0x00, 
  0x00, 0x00, 0x00, 0xc0, 0x00, 0x03, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x03, 0x00, 0x00, 0x00, 
  0x00, 0x40, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x60, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x38, 0xc0, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x3f, 0xe0, 0x03, 0x00, 0x00, 0x00, 0xe0, 0x1f, 0xd0, 0x0f, 0x00, 
  0x00, 0x00, 0xf0, 0x1f, 0xc8, 0x3f, 0x00, 0x00, 0x00, 0xf0, 0x1f, 0xc0, 0xff, 0x00, 0x00, 0x00, 
  0xf0, 0x3f, 0xe3, 0xe7, 0x01, 0x00, 0x00, 0xf8, 0x7f, 0xf0, 0xc7, 0x03, 0x00, 0x00, 0xf8, 0x7f, 
  0xff, 0x87, 0x03, 0x00, 0x00, 0xf8, 0x3f, 0xfe, 0x0f, 0x03, 0x00, 0x00, 0xfc, 0xff, 0xf7, 0x07, 
  0x03, 0x00, 0x00, 0xfc, 0x7f, 0xfe, 0x8f, 0x03, 0x00, 0x00, 0xfc, 0x7f, 0xf3, 0x8f, 0x03, 0x00, 
  0x00, 0xfe, 0xff, 0xf8, 0x8f, 0x03, 0x00, 0x00, 0xfe, 0x7f, 0xf8, 0x0f, 0x03, 0x00, 0x00, 0xff, 
  0x7f, 0xfe, 0x1f, 0x03, 0x00, 0x00, 0xff, 0x47, 0xfc, 0x3f, 0x07, 0x00, 0x80, 0xff, 0x43, 0xfc, 
  0xff, 0x07, 0x00, 0x80, 0xff, 0x61, 0xf8, 0xff, 0x07, 0x00, 0x80, 0xff, 0x01, 0xfe, 0xff, 0x0f, 
  0x00, 0x80, 0xff, 0x41, 0xfc, 0xff, 0x1f, 0x00, 0x80, 0xff, 0x71, 0xfe, 0xff, 0x3f, 0x00, 0x80, 
  0xff, 0x7f, 0xfe, 0xff, 0x3f, 0x00, 0x00, 0xff, 0x7f, 0xfc, 0xff, 0x3f, 0x00, 0x00, 0xfc, 0x7f, 
  0xfe, 0xff, 0x1f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xff, 0x1f, 0x00, 0x00, 0x80, 0x7f, 0xfc, 0xff, 
  0x0f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xff, 0x07, 0x00, 0x00, 0x80, 0xff, 0xff, 0x7f, 0x00, 0x00, 
  0x00, 0x80, 0x7f, 0xff, 0xff, 0x00, 0x00, 0x00, 0x80, 0x7f, 0xfc, 0xff, 0x01, 0x00, 0x00, 0x80, 
  0x7f, 0xfc, 0xff, 0x01, 0x00, 0x00, 0x80, 0x7f, 0xfc, 0xff, 0x03, 0x00, 0x00, 0x80, 0x7f, 0xfc, 
  0xff, 0x03, 0x00, 0x00, 0x80, 0x7f, 0xfc, 0xff, 0x03, 0x00, 0x00, 0x80, 0x7f, 0xf8, 0xff, 0x03, 
  0x00, 0x00, 0x80, 0x7f, 0xf8, 0xff, 0x03, 0x00
};
// 'frame_35_delay-0', 56x56px
const unsigned char rick_roll_frame_35_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xff, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xff, 0x01, 0x00, 
  0x00, 0x00, 0x00, 0xc0, 0xff, 0x01, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x00, 0x01, 0x00, 0x00, 0x00, 
  0x00, 0x40, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x40, 
  0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x80, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x80, 
  0x01, 0x00, 0x00, 0x00, 0x00, 0x60, 0x80, 0x03, 0x00, 0x00, 0x00, 0x00, 0x78, 0x41, 0x0f, 0x00, 
  0x00, 0x00, 0x00, 0x7e, 0x00, 0x7f, 0x00, 0x00, 0x00, 0x80, 0x7f, 0x20, 0xff, 0x01, 0x00, 0x00, 
  0xc0, 0x7f, 0x10, 0xff, 0x03, 0x00, 0x00, 0xe0, 0x7f, 0x9c, 0xff, 0x07, 0x00, 0x00, 0xe0, 0xff, 
  0xf1, 0xff, 0x07, 0x00, 0x00, 0xf0, 0xff, 0xc1, 0xff, 0x07, 0x00, 0x00, 0xf0, 0xff, 0xc7, 0xff, 
  0x07, 0x00, 0x00, 0xf0, 0xff, 0xc1, 0xff, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xe1, 0xff, 0x0f, 0x00, 
  0x00, 0xf0, 0xff, 0xe1, 0xf9, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xff, 0xe3, 0x0f, 0x00, 0x00, 0xf0, 
  0xff, 0xff, 0xc1, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xe3, 0xc1, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xe3, 
  0xc1, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xe3, 0xc7, 0x07, 0x00, 0x00, 0xf0, 0xff, 0xf3, 0xc3, 0x0f, 
  0x00, 0x00, 0xf0, 0xff, 0xfb, 0xc3, 0x0f, 0x00, 0x00, 0xf8, 0xff, 0xff, 0xc7, 0x1f, 0x00, 0x00, 
  0xf8, 0xff, 0xeb, 0xff, 0x3f, 0x00, 0x00, 0x38, 0xff, 0xe3, 0xff, 0x3f, 0x00, 0x00, 0x68, 0xff, 
  0xe3, 0xff, 0x1f, 0x00, 0x00, 0x40, 0xff, 0xe3, 0xff, 0x0f, 0x00, 0x00, 0x60, 0xff, 0xff, 0xff, 
  0x0f, 0x00, 0x00, 0x20, 0xff, 0xff, 0xff, 0x07, 0x00, 0x00, 0x00, 0xff, 0xeb, 0xff, 0x03, 0x00, 
  0x00, 0xc0, 0xff, 0xff, 0x3f, 0x00, 0x00, 0x00, 0xe0, 0xff, 0xdb, 0x3f, 0x00, 0x00, 0x00, 0xc0, 
  0xff, 0xc3, 0x3f, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x83, 0x3f, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x83, 
  0x3f, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x83, 0x3f, 0x00, 0x00, 0x00, 0xe0, 0xff, 0x03, 0x3f, 0x00, 
  0x00, 0x00, 0xe0, 0xff, 0x03, 0x3f, 0x00, 0x00
};
// 'frame_36_delay-0', 56x56px
const unsigned char rick_roll_frame_36_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xff, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x80, 0xff, 0x01, 0x00, 0x00, 0x00, 0x00, 0x80, 0xff, 0x01, 0x00, 0x00, 0x00, 
  0x00, 0x80, 0xc0, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x80, 0x03, 0x00, 0x00, 0x00, 0x00, 0x40, 0x80, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x01, 
  0x00, 0x00, 0x00, 0x00, 0x40, 0x80, 0x01, 0x00, 0x00, 0x00, 0x00, 0x40, 0x80, 0x01, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x80, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x70, 0x00, 0x03, 0x00, 0x00, 0x00, 0x00, 0x7c, 0x40, 0x0f, 0x00, 0x00, 0x00, 
  0x00, 0x7f, 0x01, 0x7f, 0x00, 0x00, 0x00, 0xc0, 0x7f, 0x20, 0xff, 0x03, 0x00, 0x00, 0xe0, 0x7f, 
  0x10, 0xff, 0x03, 0x00, 0x00, 0xf0, 0x7f, 0x8c, 0xff, 0x07, 0x00, 0x00, 0xf0, 0xff, 0xff, 0xff, 
  0x07, 0x00, 0x00, 0xf0, 0xff, 0xff, 0xff, 0x07, 0x00, 0x00, 0xf0, 0xff, 0xff, 0xff, 0x0f, 0x00, 
  0x00, 0xf0, 0xff, 0xff, 0xff, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xff, 0xff, 0x0f, 0x00, 0x00, 0xf0, 
  0xff, 0xff, 0xff, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xdf, 0xff, 0x07, 0x00, 0x00, 0xf0, 0xe7, 0xff, 
  0xdf, 0x07, 0x00, 0x00, 0xf0, 0xe1, 0xc3, 0xbf, 0x07, 0x00, 0x00, 0xf8, 0xf3, 0xf7, 0x1f, 0x06, 
  0x00, 0x00, 0xf8, 0xe5, 0xc7, 0x1f, 0x0c, 0x00, 0x00, 0xf8, 0xe9, 0xc7, 0x1f, 0x0c, 0x00, 0x00, 
  0xf8, 0xf1, 0x87, 0x1f, 0x1e, 0x00, 0x00, 0xf8, 0xf1, 0x87, 0x1f, 0x3e, 0x00, 0x00, 0xf8, 0xf1, 
  0xcf, 0x3f, 0x3f, 0x00, 0x00, 0xf8, 0xff, 0x8f, 0x7f, 0x3f, 0x00, 0x00, 0xf8, 0xff, 0xdf, 0xff, 
  0x3f, 0x00, 0x00, 0xf8, 0xff, 0xff, 0xff, 0x1f, 0x00, 0x00, 0xf8, 0xff, 0xdf, 0xff, 0x1f, 0x00, 
  0x00, 0xf0, 0xff, 0x1f, 0xfe, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xdf, 0xff, 0x07, 0x00, 0x00, 0x00, 
  0xfe, 0xdf, 0xff, 0x00, 0x00, 0x00, 0x00, 0xff, 0xdf, 0xf9, 0x00, 0x00, 0x00, 0x00, 0xff, 0x1f, 
  0xf8, 0x01, 0x00, 0x00, 0x00, 0xff, 0x1f, 0xf0, 0x01, 0x00, 0x00, 0x00, 0xff, 0x1f, 0xf0, 0x03, 
  0x00, 0x00, 0x80, 0xff, 0x1f, 0xe0, 0x03, 0x00
};
// 'frame_37_delay-0', 56x56px
const unsigned char rick_roll_frame_37_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0xff, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x80, 0xff, 0x01, 0x00, 0x00, 0x00, 0x00, 0x80, 0xff, 0x01, 0x00, 0x00, 0x00, 
  0x00, 0x80, 0xc0, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x80, 0x03, 0x00, 0x00, 0x00, 0x00, 0x40, 0x80, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x01, 
  0x00, 0x00, 0x00, 0x00, 0x40, 0x80, 0x01, 0x00, 0x00, 0x00, 0x00, 0x40, 0x80, 0x01, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x80, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x70, 0x00, 0x03, 0x00, 0x00, 0x00, 0x00, 0x7c, 0x40, 0x0f, 0x00, 0x00, 0x00, 
  0x00, 0x7f, 0x01, 0x7f, 0x00, 0x00, 0x00, 0xc0, 0x7f, 0x20, 0xff, 0x03, 0x00, 0x00, 0xe0, 0x7f, 
  0x10, 0xff, 0x03, 0x00, 0x00, 0xf0, 0x7f, 0x8c, 0xff, 0x07, 0x00, 0x00, 0xf0, 0xff, 0xff, 0xff, 
  0x07, 0x00, 0x00, 0xf0, 0xff, 0xff, 0xff, 0x07, 0x00, 0x00, 0xf0, 0xff, 0xff, 0xff, 0x0f, 0x00, 
  0x00, 0xf0, 0xff, 0xff, 0xff, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xff, 0xff, 0x0f, 0x00, 0x00, 0xf0, 
  0xff, 0xff, 0xff, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xdf, 0xff, 0x07, 0x00, 0x00, 0xf0, 0xe7, 0xff, 
  0xdf, 0x07, 0x00, 0x00, 0xf0, 0xe1, 0xc3, 0xbf, 0x07, 0x00, 0x00, 0xf8, 0xf3, 0xf7, 0x1f, 0x06, 
  0x00, 0x00, 0xf8, 0xe5, 0xc7, 0x1f, 0x0c, 0x00, 0x00, 0xf8, 0xe9, 0xc7, 0x1f, 0x0c, 0x00, 0x00, 
  0xf8, 0xf1, 0x87, 0x1f, 0x1e, 0x00, 0x00, 0xf8, 0xf1, 0x87, 0x1f, 0x3e, 0x00, 0x00, 0xf8, 0xf1, 
  0xcf, 0x3f, 0x3f, 0x00, 0x00, 0xf8, 0xff, 0x8f, 0x7f, 0x3f, 0x00, 0x00, 0xf8, 0xff, 0xdf, 0xff, 
  0x3f, 0x00, 0x00, 0xf8, 0xff, 0xff, 0xff, 0x1f, 0x00, 0x00, 0xf8, 0xff, 0xdf, 0xff, 0x1f, 0x00, 
  0x00, 0xf0, 0xff, 0x1f, 0xfe, 0x0f, 0x00, 0x00, 0xf0, 0xff, 0xdf, 0xff, 0x07, 0x00, 0x00, 0x00, 
  0xfe, 0xdf, 0xff, 0x00, 0x00, 0x00, 0x00, 0xff, 0xdf, 0xf9, 0x00, 0x00, 0x00, 0x00, 0xff, 0x1f, 
  0xf8, 0x01, 0x00, 0x00, 0x00, 0xff, 0x1f, 0xf0, 0x01, 0x00, 0x00, 0x00, 0xff, 0x1f, 0xf0, 0x03, 
  0x00, 0x00, 0x80, 0xff, 0x1f, 0xe0, 0x03, 0x00
};
// 'frame_38_delay-0', 56x56px
const unsigned char rick_roll_frame_38_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 
  0x0f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x1f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0x3f, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0xfc, 0x3f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x38, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x04, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0xd3, 
  0x04, 0x00, 0x00, 0x00, 0x00, 0x80, 0x07, 0x04, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x07, 0x1c, 0x00, 
  0x00, 0x00, 0x00, 0xf8, 0x03, 0x3a, 0x00, 0x00, 0x00, 0x00, 0xff, 0x0b, 0xf8, 0x00, 0x00, 0x00, 
  0x80, 0xff, 0x03, 0xf9, 0x03, 0x00, 0x00, 0xc0, 0xff, 0x83, 0xf8, 0x07, 0x00, 0x00, 0xc0, 0xff, 
  0x63, 0xf8, 0x1f, 0x00, 0x00, 0xe0, 0xff, 0x7f, 0xf8, 0x3f, 0x00, 0x00, 0xe0, 0xff, 0x0f, 0xff, 
  0x3f, 0x00, 0x00, 0xe0, 0xff, 0xdf, 0xfd, 0x3f, 0x00, 0x00, 0xe0, 0xff, 0xdf, 0xfd, 0x3f, 0x00, 
  0x00, 0xe0, 0xff, 0x9f, 0xfd, 0x3f, 0x00, 0x00, 0xe0, 0xff, 0x7f, 0xfc, 0x3f, 0x00, 0x00, 0xf0, 
  0xff, 0x19, 0xfe, 0x3f, 0x00, 0x00, 0xf0, 0x7f, 0x1c, 0xff, 0x3f, 0x00, 0x00, 0xf8, 0x3f, 0x78, 
  0xfc, 0x3f, 0x00, 0x00, 0xf8, 0x3f, 0x3e, 0xfe, 0x3f, 0x00, 0x00, 0xf8, 0x3f, 0x3c, 0xfe, 0x3f, 
  0x00, 0x00, 0xfc, 0x3f, 0xb8, 0xff, 0x3f, 0x00, 0x00, 0xfc, 0x3f, 0xfe, 0xfc, 0x7f, 0x00, 0x00, 
  0xfc, 0x3f, 0x7e, 0xfc, 0x7f, 0x00, 0x00, 0xfc, 0x3f, 0x3f, 0xfc, 0x7f, 0x00, 0x00, 0xfc, 0xff, 
  0x7f, 0xfd, 0x7f, 0x00, 0x00, 0xfc, 0xff, 0x7f, 0xfc, 0x7f, 0x00, 0x00, 0xfc, 0xff, 0x7f, 0xfc, 
  0x7f, 0x08, 0x00, 0xfc, 0xff, 0x7f, 0xf8, 0x3f, 0x0a, 0x00, 0xf8, 0xff, 0xff, 0xf8, 0x3f, 0x08, 
  0x00, 0xf0, 0xff, 0xff, 0xf9, 0x3f, 0x06, 0x00, 0xf0, 0xff, 0xff, 0xf7, 0x7f, 0x04, 0x00, 0x00, 
  0xfc, 0xff, 0xf3, 0xff, 0x03, 0x00, 0x00, 0xfc, 0xff, 0xfb, 0xff, 0x03, 0x00, 0x00, 0xfe, 0xff, 
  0xe0, 0xff, 0x01, 0x00, 0x00, 0xfe, 0xff, 0xc0, 0x1f, 0x00, 0x00, 0x00, 0xfe, 0xff, 0xc0, 0x07, 
  0x00, 0x00, 0x00, 0xfe, 0xff, 0xc0, 0x0f, 0x00
};
// 'frame_39_delay-0', 56x56px
const unsigned char rick_roll_frame_39_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 
  0x0f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x1f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0x3f, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0xfc, 0x3f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x38, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x04, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0xd3, 
  0x04, 0x00, 0x00, 0x00, 0x00, 0x80, 0x07, 0x04, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x07, 0x1c, 0x00, 
  0x00, 0x00, 0x00, 0xf8, 0x03, 0x3a, 0x00, 0x00, 0x00, 0x00, 0xff, 0x0b, 0xf8, 0x00, 0x00, 0x00, 
  0x80, 0xff, 0x03, 0xf9, 0x03, 0x00, 0x00, 0xc0, 0xff, 0x83, 0xf8, 0x07, 0x00, 0x00, 0xc0, 0xff, 
  0x63, 0xf8, 0x1f, 0x00, 0x00, 0xe0, 0xff, 0x7f, 0xf8, 0x3f, 0x00, 0x00, 0xe0, 0xff, 0x0f, 0xff, 
  0x3f, 0x00, 0x00, 0xe0, 0xff, 0xdf, 0xfd, 0x3f, 0x00, 0x00, 0xe0, 0xff, 0xdf, 0xfd, 0x3f, 0x00, 
  0x00, 0xe0, 0xff, 0x9f, 0xfd, 0x3f, 0x00, 0x00, 0xe0, 0xff, 0x7f, 0xfc, 0x3f, 0x00, 0x00, 0xf0, 
  0xff, 0x19, 0xfe, 0x3f, 0x00, 0x00, 0xf0, 0x7f, 0x1c, 0xff, 0x3f, 0x00, 0x00, 0xf8, 0x3f, 0x78, 
  0xfc, 0x3f, 0x00, 0x00, 0xf8, 0x3f, 0x3e, 0xfe, 0x3f, 0x00, 0x00, 0xf8, 0x3f, 0x3c, 0xfe, 0x3f, 
  0x00, 0x00, 0xfc, 0x3f, 0xb8, 0xff, 0x3f, 0x00, 0x00, 0xfc, 0x3f, 0xfe, 0xfc, 0x7f, 0x00, 0x00, 
  0xfc, 0x3f, 0x7e, 0xfc, 0x7f, 0x00, 0x00, 0xfc, 0x3f, 0x3f, 0xfc, 0x7f, 0x00, 0x00, 0xfc, 0xff, 
  0x7f, 0xfd, 0x7f, 0x00, 0x00, 0xfc, 0xff, 0x7f, 0xfc, 0x7f, 0x00, 0x00, 0xfc, 0xff, 0x7f, 0xfc, 
  0x7f, 0x08, 0x00, 0xfc, 0xff, 0x7f, 0xf8, 0x3f, 0x0a, 0x00, 0xf8, 0xff, 0xff, 0xf8, 0x3f, 0x08, 
  0x00, 0xf0, 0xff, 0xff, 0xf9, 0x3f, 0x06, 0x00, 0xf0, 0xff, 0xff, 0xf7, 0x7f, 0x04, 0x00, 0x00, 
  0xfc, 0xff, 0xf3, 0xff, 0x03, 0x00, 0x00, 0xfc, 0xff, 0xfb, 0xff, 0x03, 0x00, 0x00, 0xfe, 0xff, 
  0xe0, 0xff, 0x01, 0x00, 0x00, 0xfe, 0xff, 0xc0, 0x1f, 0x00, 0x00, 0x00, 0xfe, 0xff, 0xc0, 0x07, 
  0x00, 0x00, 0x00, 0xfe, 0xff, 0xc0, 0x0f, 0x00
};
// 'frame_40_delay-0', 56x56px
const unsigned char rick_roll_frame_40_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfc, 
  0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfe, 0x03, 0x00, 0x00, 0x00, 0x00, 0x80, 0xff, 0x03, 0x00, 
  0x00, 0x00, 0x00, 0x80, 0xff, 0x03, 0x00, 0x00, 0x00, 0x00, 0x80, 0x1f, 0x02, 0x00, 0x00, 0x00, 
  0x00, 0xc0, 0x0f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x0f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 
  0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x04, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x01, 0x02, 0x00, 0x00, 
  0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0xc0, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 0x40, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x7e, 0xc1, 0x03, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x82, 0x0f, 0x00, 
  0x00, 0x00, 0xe0, 0xff, 0x20, 0x3f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x80, 0x7f, 0x00, 0x00, 0x00, 
  0xf0, 0xff, 0xbd, 0xff, 0x00, 0x00, 0x00, 0xf0, 0xff, 0xe3, 0xff, 0x00, 0x00, 0x00, 0xf8, 0xff, 
  0xff, 0xff, 0x00, 0x00, 0x00, 0xf8, 0xff, 0xff, 0xff, 0x00, 0x00, 0x00, 0xf8, 0xff, 0xff, 0xff, 
  0x00, 0x00, 0x00, 0xf8, 0xff, 0xf7, 0xff, 0x00, 0x00, 0x00, 0xfc, 0xff, 0xff, 0xff, 0x01, 0x00, 
  0x00, 0xfc, 0xff, 0xff, 0xff, 0x01, 0x00, 0x00, 0xfc, 0xff, 0xcf, 0xff, 0x01, 0x00, 0x00, 0xfe, 
  0xff, 0xff, 0xff, 0x01, 0x00, 0x00, 0xfe, 0xff, 0x0f, 0xff, 0x01, 0x00, 0x00, 0xfe, 0xff, 0x83, 
  0xff, 0x01, 0x00, 0x00, 0xfe, 0xff, 0xc1, 0xff, 0x01, 0x00, 0x00, 0xfe, 0xff, 0x83, 0xff, 0x01, 
  0x00, 0x00, 0xfe, 0xff, 0xc3, 0xff, 0x03, 0x00, 0x00, 0xfe, 0xff, 0xe3, 0xff, 0x0f, 0x01, 0x00, 
  0xfe, 0xff, 0xff, 0xff, 0x7f, 0x01, 0x00, 0xfe, 0xff, 0xff, 0xff, 0x1f, 0x18, 0x00, 0xfc, 0xff, 
  0xff, 0xff, 0x1f, 0x78, 0x00, 0xf8, 0xff, 0xbf, 0xff, 0x1f, 0x10, 0x00, 0x80, 0xff, 0xff, 0xff, 
  0x3f, 0x78, 0x00, 0x80, 0xff, 0xff, 0x3f, 0x7c, 0x1d, 0x00, 0x80, 0xff, 0xbf, 0x3f, 0xc0, 0x14, 
  0x00, 0x80, 0xff, 0x3f, 0x3f, 0x00, 0x00, 0x00, 0x80, 0xff, 0x3f, 0x3f, 0x00, 0x00, 0x00, 0x80, 
  0xff, 0x3f, 0x3f, 0x00, 0x00, 0x00, 0x80, 0xff, 0x3f, 0x3e, 0x00, 0x00, 0x00, 0x80, 0xff, 0x3f, 
  0x3e, 0x00, 0x00, 0x00, 0x80, 0xff, 0x3f, 0x3c, 0x00, 0x00, 0x00, 0x80, 0xff, 0x3f, 0x3c, 0x00, 
  0x00, 0x00, 0x80, 0xff, 0x7f, 0x38, 0x00, 0x00
};
// 'frame_41_delay-0', 56x56px
const unsigned char rick_roll_frame_41_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x3f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x7f, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0x7f, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0xf8, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x78, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 
  0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x60, 0x40, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x30, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x38, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1c, 0xf0, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x1f, 0xe0, 0x03, 0x00, 0x00, 0x00, 0xc0, 0x1f, 0xe0, 0x0f, 0x00, 
  0x00, 0x00, 0xf0, 0x9f, 0xc0, 0x1f, 0x00, 0x00, 0x00, 0xfc, 0x1f, 0xe5, 0x3f, 0x00, 0x00, 0x00, 
  0xfe, 0x3f, 0xe3, 0x3f, 0x00, 0x00, 0x00, 0xfe, 0xff, 0xff, 0x7f, 0x00, 0x00, 0x00, 0xfe, 0xff, 
  0xf0, 0x7f, 0x00, 0x00, 0x00, 0xfe, 0xff, 0xf1, 0x7f, 0x00, 0x00, 0x00, 0xff, 0xff, 0xfb, 0x7f, 
  0x00, 0x00, 0x00, 0xff, 0xff, 0xf0, 0x7f, 0x00, 0x00, 0x00, 0xff, 0xff, 0xff, 0x7f, 0x00, 0x00, 
  0x00, 0xff, 0xff, 0xff, 0x7f, 0x00, 0x00, 0x00, 0xff, 0xff, 0xfd, 0x7f, 0x00, 0x00, 0x00, 0xff, 
  0xff, 0xf3, 0x7f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xf3, 0x7f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xf3, 
  0x7f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xf3, 0x6f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xff, 0x87, 0x00, 
  0x00, 0x80, 0xff, 0xff, 0xf7, 0x2f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xff, 0x0f, 0x00, 0x00, 0xc0, 
  0xff, 0xff, 0xff, 0x8f, 0x00, 0x00, 0xc0, 0xff, 0x7f, 0xfe, 0x8f, 0x00, 0x00, 0x80, 0xff, 0x9f, 
  0xf7, 0x1f, 0x00, 0x00, 0x00, 0xff, 0x4f, 0xec, 0xff, 0x00, 0x00, 0x00, 0xff, 0x87, 0xed, 0x7f, 
  0x00, 0x00, 0x00, 0xfe, 0x07, 0xff, 0x7f, 0x00, 0x00, 0x00, 0xfc, 0x07, 0xfe, 0x07, 0x00, 0x00, 
  0x00, 0xf0, 0x07, 0xcf, 0x0f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0xcf, 0x0f, 0x00, 0x00, 0x00, 0xf0, 
  0xff, 0xcf, 0x0f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 0x0f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 
  0x1f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 0x1f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 0x1f, 0x00, 
  0x00, 0x00, 0xf0, 0xff, 0x0f, 0x1f, 0x00, 0x00
};
// 'frame_42_delay-0', 56x56px
const unsigned char rick_roll_frame_42_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x3f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x7f, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0x7f, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0xf8, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x78, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 
  0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x60, 0x40, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x30, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x38, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1c, 0xf0, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x1f, 0xe0, 0x03, 0x00, 0x00, 0x00, 0xc0, 0x1f, 0xe0, 0x0f, 0x00, 
  0x00, 0x00, 0xf0, 0x9f, 0xc0, 0x1f, 0x00, 0x00, 0x00, 0xfc, 0x1f, 0xe5, 0x3f, 0x00, 0x00, 0x00, 
  0xfe, 0x3f, 0xe3, 0x3f, 0x00, 0x00, 0x00, 0xfe, 0xff, 0xff, 0x7f, 0x00, 0x00, 0x00, 0xfe, 0xff, 
  0xf0, 0x7f, 0x00, 0x00, 0x00, 0xfe, 0xff, 0xf1, 0x7f, 0x00, 0x00, 0x00, 0xff, 0xff, 0xfb, 0x7f, 
  0x00, 0x00, 0x00, 0xff, 0xff, 0xf0, 0x7f, 0x00, 0x00, 0x00, 0xff, 0xff, 0xff, 0x7f, 0x00, 0x00, 
  0x00, 0xff, 0xff, 0xff, 0x7f, 0x00, 0x00, 0x00, 0xff, 0xff, 0xfd, 0x7f, 0x00, 0x00, 0x00, 0xff, 
  0xff, 0xf3, 0x7f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xf3, 0x7f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xf3, 
  0x7f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xf3, 0x6f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xff, 0x87, 0x00, 
  0x00, 0x80, 0xff, 0xff, 0xf7, 0x2f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xff, 0x0f, 0x00, 0x00, 0xc0, 
  0xff, 0xff, 0xff, 0x8f, 0x00, 0x00, 0xc0, 0xff, 0x7f, 0xfe, 0x8f, 0x00, 0x00, 0x80, 0xff, 0x9f, 
  0xf7, 0x1f, 0x00, 0x00, 0x00, 0xff, 0x4f, 0xec, 0xff, 0x00, 0x00, 0x00, 0xff, 0x87, 0xed, 0x7f, 
  0x00, 0x00, 0x00, 0xfe, 0x07, 0xff, 0x7f, 0x00, 0x00, 0x00, 0xfc, 0x07, 0xfe, 0x07, 0x00, 0x00, 
  0x00, 0xf0, 0x07, 0xcf, 0x0f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0xcf, 0x0f, 0x00, 0x00, 0x00, 0xf0, 
  0xff, 0xcf, 0x0f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 0x0f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 
  0x1f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 0x1f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 0x1f, 0x00, 
  0x00, 0x00, 0xf0, 0xff, 0x0f, 0x1f, 0x00, 0x00
};
// 'frame_43_delay-0', 56x56px
const unsigned char rick_roll_frame_43_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x3f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x7f, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0x7f, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0xf8, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf8, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x78, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 
  0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x78, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x60, 0x40, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x30, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x38, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1c, 0xf0, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x1f, 0xe0, 0x03, 0x00, 0x00, 0x00, 0xc0, 0x1f, 0xe0, 0x0f, 0x00, 
  0x00, 0x00, 0xf0, 0x9f, 0xc0, 0x1f, 0x00, 0x00, 0x00, 0xfc, 0x1f, 0xe5, 0x3f, 0x00, 0x00, 0x00, 
  0xfe, 0x3f, 0xe3, 0x3f, 0x00, 0x00, 0x00, 0xfe, 0xff, 0xff, 0x7f, 0x00, 0x00, 0x00, 0xfe, 0xff, 
  0xf0, 0x7f, 0x00, 0x00, 0x00, 0xfe, 0xff, 0xf1, 0x7f, 0x00, 0x00, 0x00, 0xff, 0xff, 0xfb, 0x7f, 
  0x00, 0x00, 0x00, 0xff, 0xff, 0xf0, 0x7f, 0x00, 0x00, 0x00, 0xff, 0xff, 0xff, 0x7f, 0x00, 0x00, 
  0x00, 0xff, 0xff, 0xff, 0x7f, 0x00, 0x00, 0x00, 0xff, 0xff, 0xfd, 0x7f, 0x00, 0x00, 0x00, 0xff, 
  0xff, 0xf3, 0x7f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xf3, 0x7f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xf3, 
  0x7f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xf3, 0x6f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xff, 0x87, 0x00, 
  0x00, 0x80, 0xff, 0xff, 0xf7, 0x2f, 0x00, 0x00, 0x80, 0xff, 0xff, 0xff, 0x0f, 0x00, 0x00, 0xc0, 
  0xff, 0xff, 0xff, 0x8f, 0x00, 0x00, 0xc0, 0xff, 0x7f, 0xfe, 0x8f, 0x00, 0x00, 0x80, 0xff, 0x9f, 
  0xf7, 0x1f, 0x00, 0x00, 0x00, 0xff, 0x4f, 0xec, 0xff, 0x00, 0x00, 0x00, 0xff, 0x87, 0xed, 0x7f, 
  0x00, 0x00, 0x00, 0xfe, 0x07, 0xff, 0x7f, 0x00, 0x00, 0x00, 0xfc, 0x07, 0xfe, 0x07, 0x00, 0x00, 
  0x00, 0xf0, 0x07, 0xcf, 0x0f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0xcf, 0x0f, 0x00, 0x00, 0x00, 0xf0, 
  0xff, 0xcf, 0x0f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 0x0f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 
  0x1f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 0x1f, 0x00, 0x00, 0x00, 0xf0, 0xff, 0x8f, 0x1f, 0x00, 
  0x00, 0x00, 0xf0, 0xff, 0x0f, 0x1f, 0x00, 0x00
};
// 'frame_44_delay-0', 56x56px
const unsigned char rick_roll_frame_44_delay_0 [] PROGMEM = {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x1f, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x7f, 0x00, 0x00, 
  0x00, 0x00, 0x00, 0xf0, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x60, 0x00, 0x00, 0x00, 0x00, 
  0x00, 0x10, 0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 
  0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x80, 0x00, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 
  0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x20, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 
  0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc6, 
  0x00, 0x00, 0x00, 0x00, 0x00, 0x20, 0x80, 0x07, 0x00, 0x00, 0x00, 0x00, 0x70, 0x00, 0x7f, 0x00, 
  0x00, 0x00, 0x00, 0x7c, 0x00, 0xff, 0x01, 0x00, 0x00, 0x00, 0xbf, 0x20, 0xff, 0x07, 0x00, 0x00, 
  0xc0, 0x3f, 0x01, 0xff, 0x07, 0x00, 0x00, 0xf0, 0x3f, 0x12, 0xff, 0x07, 0x00, 0x00, 0xf0, 0x3f, 
  0x0c, 0xff, 0x07, 0x00, 0x00, 0xf8, 0x7f, 0xf7, 0xff, 0x07, 0x00, 0x00, 0xf8, 0xff, 0x81, 0xff, 
  0x07, 0x00, 0x00, 0xf8, 0xff, 0x80, 0xff, 0x0f, 0x00, 0x00, 0xf8, 0xff, 0x87, 0xff, 0x0f, 0x00, 
  0x00, 0xf8, 0xff, 0x81, 0xff, 0x0f, 0x00, 0x00, 0xf8, 0xff, 0xff, 0xff, 0x0f, 0x00, 0x00, 0xf8, 
  0xff, 0xc3, 0xff, 0x0f, 0x00, 0x00, 0xf8, 0xff, 0x83, 0xff, 0x1f, 0x00, 0x00, 0xf8, 0xff, 0x83, 
  0xff, 0x1f, 0x00, 0x00, 0xf8, 0xff, 0x87, 0xff, 0x1f, 0x00, 0x00, 0xf8, 0xff, 0x87, 0xff, 0x1f, 
  0x00, 0x00, 0xf8, 0xff, 0x87, 0x3f, 0x3e, 0x00, 0x00, 0xf8, 0xff, 0x87, 0x7f, 0x7c, 0x00, 0x00, 
  0xf8, 0xff, 0xff, 0x3f, 0x38, 0x00, 0x00, 0xec, 0xff, 0x87, 0x1f, 0x18, 0x00, 0x00, 0x98, 0xff, 
  0x07, 0x7f, 0x1c, 0x00, 0x00, 0x60, 0xff, 0x7f, 0x7f, 0x1c, 0x00, 0x00, 0xcc, 0xfe, 0x1f, 0xff, 
  0x0f, 0x00, 0x00, 0x08, 0xfe, 0xff, 0xfe, 0x03, 0x00, 0x00, 0xd8, 0xff, 0x0f, 0xfe, 0x01, 0x00, 
  0x00, 0x98, 0xff, 0x3f, 0x7e, 0x00, 0x00, 0x00, 0xd8, 0xff, 0xbf, 0x7f, 0x00, 0x00, 0x00, 0xf0, 
  0xff, 0xbf, 0xff, 0x00, 0x00, 0x00, 0x80, 0xff, 0x0f, 0xf8, 0x00, 0x00, 0x00, 0x80, 0xff, 0x0f, 
  0xf8, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x0f, 0xf0, 0x00, 0x00, 0x00, 0xc0, 0xff, 0x0f, 0xf0, 0x00, 
  0x00, 0x00, 0xc0, 0xff, 0x0f, 0xe0, 0x01, 0x00
};

// Array of all bitmaps for convenience. (Total bytes used to store images in PROGMEM = 18720)
const int rick_roll_animARRAY_LEN = 45;
const unsigned char* rick_roll_anim[45] = {
  rick_roll_frame_00_delay_0,
  rick_roll_frame_01_delay_0,
  rick_roll_frame_02_delay_0,
  rick_roll_frame_03_delay_0,
  rick_roll_frame_04_delay_0,
  rick_roll_frame_05_delay_0,
  rick_roll_frame_06_delay_0,
  rick_roll_frame_07_delay_0,
  rick_roll_frame_08_delay_0,
  rick_roll_frame_09_delay_0,
  rick_roll_frame_10_delay_0,
  rick_roll_frame_11_delay_0,
  rick_roll_frame_12_delay_0,
  rick_roll_frame_13_delay_0,
  rick_roll_frame_14_delay_0,
  rick_roll_frame_15_delay_0,
  rick_roll_frame_16_delay_0,
  rick_roll_frame_17_delay_0,
  rick_roll_frame_18_delay_0,
  rick_roll_frame_19_delay_0,
  rick_roll_frame_20_delay_0,
  rick_roll_frame_21_delay_0,
  rick_roll_frame_22_delay_0,
  rick_roll_frame_23_delay_0,
  rick_roll_frame_24_delay_0,
  rick_roll_frame_25_delay_0,
  rick_roll_frame_26_delay_0,
  rick_roll_frame_27_delay_0,
  rick_roll_frame_28_delay_0,
  rick_roll_frame_29_delay_0,
  rick_roll_frame_30_delay_0,
  rick_roll_frame_31_delay_0,
  rick_roll_frame_32_delay_0,
  rick_roll_frame_33_delay_0,
  rick_roll_frame_34_delay_0,
  rick_roll_frame_35_delay_0,
  rick_roll_frame_36_delay_0,
  rick_roll_frame_37_delay_0,
  rick_roll_frame_38_delay_0,
  rick_roll_frame_39_delay_0,
  rick_roll_frame_40_delay_0,
  rick_roll_frame_41_delay_0,
  rick_roll_frame_42_delay_0,
  rick_roll_frame_43_delay_0,
  rick_roll_frame_44_delay_0
};

/*
 * Animation
*/
void display_frame(char* frame_name) {
  u8g2.setBitmapMode(true /* transparent */);
  u8g2.drawXBMP(30, 0, 56, 56, frame_name);
}

void setup(void) {
  u8g2.begin(); //Initialize the function
}

uint8_t frame_num = 0;

void loop(void) {
  // picture loop  
  u8g2.firstPage();
  do {
    display_frame(rick_roll_anim[frame_num]);
  } while( u8g2.nextPage() );

  frame_num++;

  if (frame_num >= rick_roll_animARRAY_LEN){
    frame_num=0;
  }
  delay(80);
}
